

/*

1. Append years
2. Make Vars 
3. Merge ACG
4. Define estimation sample flag

*/


*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
* Load data 
*----------------------------------------------------
*----------------------------------------------------


clear
clear mata
clear matrix
*set mem 6g
set more off

global SOURCE "/disk/aging/medstat/data/sas"
global BULK "/disk/agebulk2/medstat.work/gerusom"
global WORK "/disk/agedisk3/medstat.work/gerusom"
global SCRATCH "/disk/agescratch4/gerusom"


use "$WORK/Data/Cleaned_merged_MAY072011.dta", clear


*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
*More Vars
*----------------------------------------------------
*----------------------------------------------------

keep if count_fam==1

*----Plan choice 

cap drop chooseB
gen chooseB = .
replace chooseB = 1 if (B_sal==1|B_hour==1)
replace chooseB = 0 if (B_sal==0|B_hour==0)
//replace chooseB = 1 if year==2004

ta chooseB year, mis

forvalues yr=5(1)7{
	cap drop temp*
	egen temp = total(chooseB) if year == 200`yr', by(enrolid)
	cap drop B_200`yr'
	egen B_200`yr' = max(temp), by(enrolid)

}

cap drop B_last
gen B_last = 0 if year==2005 | year==2006 | year==2007
replace B_last = 1 if B_2005==1 & year==2005 
replace B_last = 1 if B_2005==1 & year==2006
replace B_last = 1 if B_2006==1 & year==2007
label var B_last "In plan H t-1"

ta B_2005 B_2006 if year==2006, mis
gen B_05_06 =  B_2005*B_2006


*---more vars
*ta region, gen(I_region_)
*ta fips, gen(I_state_)
*ta ege, gen(I_state_)



*----Demographics

label var fem "female"
label var I_ag2_2 "age_30-39"
label var I_ag2_3 "age_40-49"
label var I_ag2_4 "age_50-59"

ta region, gen(I_region_)

gen ag3 = .
replace ag3 = 1 if age>=18 & age<=24
replace ag3 = 2 if age>=25 & age<=29
replace ag3 = 3 if age>=30 & age<=34
replace ag3 = 4 if age>=35 & age<=39
replace ag3 = 5 if age>=40 & age<=44
replace ag3 = 6 if age>=45 & age<=49
replace ag3 = 7 if age>=50 & age<=54
replace ag3 = 8 if age>=55 & age<=59
replace ag3 = 9 if age>=60 & age<=64


*-----Panel vars

cap drop panel_t1
gen panel_t1=0 if year>=2004 & year<=2007
replace panel_t1 = 1 if year==2004 & totpay_2003~=.
replace panel_t1 = 1 if year==2005 & totpay_2004~=.
replace panel_t1 = 1 if year==2006 & totpay_2005~=.
replace panel_t1 = 1 if year==2007 & totpay_2006~=.

cap drop panel_t2
gen panel_t2=0 if year>=2005 & year<=2007
replace panel_t2 = 1 if year==2005 & totpay_2003~=.
replace panel_t2 = 1 if year==2006 & totpay_2004~=.
replace panel_t2 = 1 if year==2007 & totpay_2005~=.

cap drop last_totpay
gen last_totpay = .
replace last_totpay = totpay_2004 if year==2005
replace last_totpay = totpay_2005 if year==2006
replace last_totpay = totpay_2006 if year==2007


*---expected and actual spending

cap drop ln_preddoc
cap drop ln_predtot
gen ln_preddoc = ln(preddoc)
gen ln_predtot = ln(predtot)

cap drop ln_totpay 
gen ln_totpay = ln(totpay + 100)

cap drop ln_totpay
gen ln_totpay = ln(totpay)
	
cap drop ln_transtotpay
gen ln_transtotpay = ln(totpay+100)
	
cap drop ln_last_totpay
gen ln_last_totpay = ln(last_totpay)

cap drop ln_last_transtotpay
gen ln_last_transtotpay = ln(last_totpay+100)


*---variance proxy

*error = F(abs(actual - predicted))

cap drop error*
cap drop lnerror

gen prederrdoc = totdoc - preddoc
gen errorsigned = predtot - totpay
gen error = abs(predtot - totpay)
gen errorsq = error*error
gen lnerror = ln(abs(predtot - totpay))
gen lnerrorsq = ln(errorsq)
gen errorln = abs(ln_predtot - ln_totpay)
gen errorlnsq = errorln*errorln

label var errorsigned "prediction error of total consumption in levels"
label var error "absolute error of total consumption in levels"
label var lnerror "ln of absolute error of total consumption in levels"
label var errorln "error of total consumption logs"


*---first time enrollees


cap drop firstyear
gen firstyear = .
forvalues yr=4(1)7{
	local last = `yr' - 1
	replace firstyear=1 if insample_200`last'==0 & insample_200`yr'==1 & year==200`yr'
}


forvalues i=1(1)4{
	gen I_ag2_`i'_ln_predtot = I_ag2_`i'*ln_predtot
}

gen predtot_next = .
replace predtot_next = pred_tot_2006 if year==2005
replace predtot_next = pred_tot_2007 if year==2006

*gen I_fem_ln_predtot = fem*ln_predtot

*cap drop I_state*
*ta egeoloc, gen(I_state_)


save "$WORK/Data/Main_2016.dta", replace
