clear
set mem 15g
set more off

global SOURCE "/disk/aging/medstat/data/sas"
global BULK "/disk/agebulk2/medstat.work/gerusom"
global WORK "/disk/agedisk3/medstat.work/gerusom"

*----
/*

This do file preformats inputs into the ACG system

PART A:
1. It creates summaries of total cost by in/out/pharma
2. It creates counts of in/outpat episodes
3. It saves to a single file, culled of unneeded vars

PARTB:
1. Creates formatted tab-delim txt file for Patient input to ACG
2. Creates formatted tab-delim txt file for Medical input to ACG
3. Creates formatted tab-delim txt file for Drug input to ACG

*/


*---------------------------------------------------
*PART A
*---------------------------------------------------

set more off
*---2003-2004
forvalues i=3(1)4{

	*----Construct enrolid roster
	
	use "$BULK/ccaee200`i'.dta", clear
	keep if (plank>=2500 &  plank<=2529)
	egen tot_memdays = total(memdays), by(enrolid)
	keep if tot_memdays>=300
	
	egen tag_id = tag(enrolid)
	keep if tag_id==1

	*get family id, which is just enrolid except for last two digits
	tostring enrolid, gen(patient_id) force
	gen idreverse = reverse(patient_id)
	gen famreverse = substr(idreverse, 3,.)
	gen famid = reverse(famreverse)

	*----
	*---OUTPATIENT
	merge 1:m enrolid using "$BULK/ccaeo200`i'.dta",
	*drop utilization claims for claimants not in the sample of interest
	*the outpatient file has ppl from other plans/companies
	*as well as ppl from this company with <300 days membership
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1 & (plank>=2500 &  plank<=2529) & _merge==2
	count if tag_id==1 & (plank>=2500 &  plank<=2529) & _merge==3

	drop if _merge==2

	keep enrolid patient_id age region plankey eeclass eestatu egeoloc /*
	 */ emprel sex urban famid svcdate cob copay deduct netpay pay /*
	 */ stdplac stdprov stdsvc procgrp proctyp year

	*----Count outpatient vists/ER visits

	*define a visit by a unique date of visit
	egen tag_visits = tag(enrolid svcdate)
	egen outpatient_visits = total(tag_visits), by(enrolid)
	replace outpatient_visits = 100 if outpatient_visits>100
		
	*tally ER visits 23
	egen temp_er = tag(enrolid svcdate) if (stdplac==23)
	egen emergency_visits = total(temp_er), by(enrolid)
	replace emergency_visits = 0 if emergency_visits==.
	

	*---Financials
	
	*2004 and earlier lump coins and copay into copay--actually, they dont report coins, will give incorrect OOP, must impute 
	egen out_copay = total(copay), by(enrolid)
	egen out_deduct = total(deduct), by(enrolid)
	egen out_totpay = total(pay), by(enrolid)

	*keep just one record per enrolid, with total utilization summarized
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1
	
	keep enrolid patient_id age region plankey eeclass eestatu egeoloc emprel sex /*
	 */ urban year outpatient_visits emergency_visits out_copay out_deduct out_totpay
	
	*----
	*----INPATIENT

	*---Financials

	*need to go to services "s" file in 2004 and earlier to get copay/coins data in inpat files
	merge 1:m enrolid using "$BULK/ccaes200`i'.dta",
	*drop utilization claims for claimants not in the sample of interest (ie. who work for different firm)
	drop if _merge==2

	egen in_copay = total(copay), by(enrolid)
	egen in_deduct = total(deduct), by(enrolid)
	egen in_totpay = total(pay), by(enrolid)

	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1
	
	keep enrolid patient_id age region plankey eeclass eestatu egeoloc emprel sex /*
	 */ urban year outpatient_visits emergency_visits out_copay out_deduct out_totpay /*
	 */ in_copay in_deduct in_totpay
	
	*----Counts of use
	
	*most convenient to use "i" file in 2004 and earlier to get number of stays
	
	cap drop _merge
	merge 1:m enrolid using "$BULK/ccaei200`i'.dta",
	*drop utilization claims for claimants not in the sample of interest (ie. who work for different firm)
	drop if _merge==2
	
	*define a visit by a unique date of admission
	egen tag_visits = tag(enrolid admdate) if admdate~=.
	egen inpatient_stays = total(tag_visits), by(enrolid)
	
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1
	
	*some checks
	ta inpatient_stays
	count if inpatient_stays>0 & in_tot==0
	count if inpatient_stays==0 & in_tot~=0

	keep enrolid patient_id age region plankey eeclass eestatu egeoloc emprel sex /*
	 */ urban year outpatient_visits emergency_visits out_copay out_deduct out_totpay /*
	 */ in_copay in_deduct in_totpay inpatient_stays

	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1

	*----
	*---PHARMA
	merge 1:m enrolid using "$BULK/ccaed200`i'.dta"
	drop if _merge==2
	
	egen pharm_copay = total(copay), by(enrolid)
	egen pharm_deduct = total(deduct), by(enrolid)
	egen pharm_totpay = total(pay), by(enrolid)

	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1
	
	keep enrolid patient_id age region plankey eeclass eestatu egeoloc emprel sex /*
	 */ urban year outpatient_visits emergency_visits out_copay out_deduct out_totpay /*
	 */ in_copay in_deduct in_totpay inpatient_stays pharm_copay pharm_deduct pharm_totpay
	
	
	save "$WORK/Costs_andCounts_200`i'.dta", replace

}


forvalues i=5(1)6{


	*----Construct enrolid roster
	
	use "$BULK/ccaee200`i'.dta", clear
	keep if (plank>=2500 &  plank<=2529)
	egen tot_memdays = total(memdays), by(enrolid)
	keep if tot_memdays>=300
	
	egen tag_id = tag(enrolid)
	keep if tag_id==1

	*get family id, which is just enrolid except for last two digits
	tostring enrolid, gen(patient_id) force
	gen idreverse = reverse(patient_id)
	gen famreverse = substr(idreverse, 3,.)
	gen famid = reverse(famreverse)

	*----
	*---OUTPATIENT
	merge 1:m enrolid using "$BULK/ccaeo200`i'a.dta",
	*drop utilization claims for claimants not in the sample of interest
	*the outpatient file has ppl from other plans/companies
	*as well as ppl from this company with <300 days membership
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1 & (plank>=2500 &  plank<=2529) & _merge==2
	count if tag_id==1 & (plank>=2500 &  plank<=2529) & _merge==3

	drop if _merge==2

 
	*----Count outpatient vists/ER visits

	*define a visit by a unique date of visit
	egen tag_visits = tag(enrolid svcdate)
	egen outpatient_visits = total(tag_visits), by(enrolid)
	replace outpatient_visits = 100 if outpatient_visits>100
		
	*tally ER visits 23
	egen temp_er = tag(enrolid svcdate) if (stdplac==23)
	egen emergency_visits = total(temp_er), by(enrolid)
	replace emergency_visits = 0 if emergency_visits==.
	

	*---Financials
	
	*2004 and earlier lump coins and copay into copay--actually, they dont report coins, will give incorrect OOP, must impute 
	egen out_copay = total(copay), by(enrolid)
	egen out_deduct = total(deduct), by(enrolid)
	egen out_totpay = total(pay), by(enrolid)
	egen out_coins = total(coins), by(enrolid)

	*keep just one record per enrolid, with total utilization summarized
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1
	
	keep enrolid patient_id age region plankey eeclass eestatu egeoloc emprel sex /*
	 */ urban year outpatient_visits emergency_visits out_copay out_deduct out_totpay out_coins
	 	

	*----
	*----INPATIENT

	*---Financials


	merge 1:m enrolid using "$BULK/ccaei200`i'.dta",
	*drop utilization claims for claimants not in the sample of interest (ie. who work for different firm)
	drop if _merge==2
	
	egen in_copay = total(totcopay), by(enrolid)
	egen in_deduct = total(totded), by(enrolid)
	egen in_totpay = total(totpay), by(enrolid)
	egen in_coins = total(totcoins), by(enrolid)
	

	*----Counts of use
	
	*most convenient to use "i" file in 2004 and earlier to get number of stays
	
	*define a visit by a unique date of admission
	egen tag_visits = tag(enrolid admdate) if admdate~=.
	egen inpatient_stays = total(tag_visits), by(enrolid)
	
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1
	
	*some checks
	ta inpatient_stays
	count if inpatient_stays>0 & in_tot==0
	count if inpatient_stays==0 & in_tot~=0

	keep enrolid patient_id age region plankey eeclass eestatu egeoloc emprel sex /*
	 */ urban year outpatient_visits emergency_visits out_copay out_deduct out_totpay out_coins /*
	 */ in_copay in_deduct in_totpay in_coins inpatient_stays

	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1

	*----
	*---PHARMA
	merge 1:m enrolid using "$BULK/ccaed200`i'.dta"
	drop if _merge==2
	
	egen pharm_copay = total(copay), by(enrolid)
	egen pharm_deduct = total(deduct), by(enrolid)
	egen pharm_totpay = total(pay), by(enrolid)
	egen pharm_coins = total(coins), by(enrolid)
	
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1
	
	keep enrolid patient_id age region plankey eeclass eestatu egeoloc emprel sex /*
	 */ urban year outpatient_visits emergency_visits out_copay out_deduct out_totpay out_coins /*
	 */ in_copay in_deduct in_totpay in_coins inpatient_stays pharm_copay pharm_deduct pharm_totpay pharm_coins
	 
	save "$WORK/Costs_andCounts_200`i'.dta", replace
}


forvalues i=7(1)7{


	*----Construct enrolid roster
	
	use "$BULK/ccaea200`i'.dta", clear
	keep if (plank_a>=2500 &  plank_a<=2531)
	keep if memdays>=300
	
	*drop ppl who switch midyear
	drop if plank_a~=plank_b
	rename plank_a plank
	drop plank_b
		
	egen tag_id = tag(enrolid)
	keep if tag_id==1

	*get family id, which is just enrolid except for last two digits
	tostring enrolid, gen(patient_id) force
	gen idreverse = reverse(patient_id)
	gen famreverse = substr(idreverse, 3,.)
	gen famid = reverse(famreverse)

	*----
	*---OUTPATIENT
	merge 1:m enrolid using "$BULK/ccaeo200`i'a.dta",
	*drop utilization claims for claimants not in the sample of interest
	*the outpatient file has ppl from other plans/companies
	*as well as ppl from this company with <300 days membership
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1 & (plank>=2500 &  plank<=2540) & _merge==2
	count if tag_id==1 & (plank>=2500 &  plank<=2540) & _merge==3

	drop if _merge==2

 
	*----Count outpatient vists/ER visits

	*define a visit by a unique date of visit
	egen tag_visits = tag(enrolid svcdate)
	egen outpatient_visits = total(tag_visits), by(enrolid)
	replace outpatient_visits = 100 if outpatient_visits>100
		
	*tally ER visits 23
	egen temp_er = tag(enrolid svcdate) if (stdplac==23)
	egen emergency_visits = total(temp_er), by(enrolid)
	replace emergency_visits = 0 if emergency_visits==.
	

	*---Financials
	
	*2004 and earlier lump coins and copay into copay--actually, they dont report coins, will give incorrect OOP, must impute 
	egen out_copay = total(copay), by(enrolid)
	egen out_deduct = total(deduct), by(enrolid)
	egen out_totpay = total(pay), by(enrolid)
	egen out_coins = total(coins), by(enrolid)

	*keep just one record per enrolid, with total utilization summarized
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1
	
	keep enrolid patient_id age region plankey eeclass eestatu egeoloc emprel sex /*
	 */ urban year outpatient_visits emergency_visits out_copay out_deduct out_totpay out_coins
	 	
	
	*----
	*----INPATIENT

	*---Financials


	merge 1:m enrolid using "$BULK/ccaei200`i'.dta",
	*drop utilization claims for claimants not in the sample of interest (ie. who work for different firm)
	drop if _merge==2
	
	egen in_copay = total(totcopay), by(enrolid)
	egen in_deduct = total(totded), by(enrolid)
	egen in_totpay = total(totpay), by(enrolid)
	egen in_coins = total(totcoins), by(enrolid)
	

	*----Counts of use
	
	*most convenient to use "i" file in 2004 and earlier to get number of stays
	
	*define a visit by a unique date of admission
	egen tag_visits = tag(enrolid admdate) if admdate~=.
	egen inpatient_stays = total(tag_visits), by(enrolid)
	
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1
	
	*some checks
	ta inpatient_stays
	count if inpatient_stays>0 & in_tot==0
	count if inpatient_stays==0 & in_tot~=0

	keep enrolid patient_id age region plankey eeclass eestatu egeoloc emprel sex /*
	 */ urban year outpatient_visits emergency_visits out_copay out_deduct out_totpay out_coins /*
	 */ in_copay in_deduct in_totpay in_coins inpatient_stays

	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1

	*----
	*---PHARMA
	merge 1:m enrolid using "$BULK/ccaed200`i'.dta"
	drop if _merge==2
	
	egen pharm_copay = total(copay), by(enrolid)
	egen pharm_deduct = total(deduct), by(enrolid)
	egen pharm_totpay = total(pay), by(enrolid)
	egen pharm_coins = total(coins), by(enrolid)
	
	cap drop tag_id
	egen tag_id = tag(enrolid)
	count if tag_id==1
	keep if tag_id==1
	
	keep enrolid patient_id age region plankey eeclass eestatu egeoloc emprel sex /*
	 */ urban year outpatient_visits emergency_visits out_copay out_deduct out_totpay out_coins /*
	 */ in_copay in_deduct in_totpay in_coins inpatient_stays pharm_copay pharm_deduct pharm_totpay pharm_coins
	 
	save "$WORK/Costs_andCounts_200`i'.dta", replace
	
}










*---------------------------------------------------
*PART B
*---------------------------------------------------




*----
*----Make Patient table

set more off
forvalues i=3(1)6{


	use "$WORK/Costs_andCounts_200`i'.dta", clear

	egen tag_id = tag(enrolid)
	count if tag_id~=1

	rename sex fem
	gen str1 sex = "M" if fem=="1"
	replace sex = "F" if fem=="2"
	ta fem sex, mis

	foreach var in out_totpay in_totpay pharm_totpay inpatient_stays outpatient_visits emergency_visits{
		replace `var' = 0 if `var' ==.
	}

	gen pharmacy_cost = pharm_totpay
	gen total_cost = pharm_totpay + out_totpay + in_totpay

	keep  patient_id age sex pharmacy_cost total_cost outpatient_visits emergency_visits inpatient_stays
	
	gen str1 line_of_business = ""
	gen str1 company = ""
	gen str1 product = ""
	gen str1 employer_group_id = ""
	gen str1 employer_group_name = ""
	gen str1 benefit_plan = ""
	gen str1 health_system = ""
	gen str1 pcp_id = ""
	gen str1 pcp_name = ""
	gen str1 pcp_group_id = ""
	gen str1 pcp_group_name = ""
	gen str1 pregnant = "0"
	gen str1 delivered = "0"
	gen str1 low_birthweight = ""
	gen str1 dialysis_service = ""
	gen str1 nursing_service = ""
	gen str1 major_procedure = ""
	
	cap drop outpatient_visits emergency_visits inpatient_stays
	gen str1 inpatient_stays = ""
	gen str1 emergency_visits = ""
	gen str1 outpatient_visits = ""

	order patient_id age sex line_of_business company product employer_group_id employer_group_name /*
	 */ benefit_plan health_system pcp_id pcp_name pcp_group_id pcp_group_name /* 
	 */ pregnant delivered low_birthweight pharmacy_cost total_cost inpatient_stays /* 
	 */ emergency_visits outpatient_visits dialysis_service nursing_service major_procedure

	outsheet using "$BULK/ACG/Patient_0`i'.txt", nolabel noquote replace
	
}
	
*----
*----Make Medical Services table

set more off
forvalues i=3(1)4{


	use "$BULK/ccaee200`i'.dta", clear
	keep if (plank>=2500 &  plank<=2529)
	egen tot_memdays = total(memdays), by(enrolid)
	keep if tot_memdays>=300
	
	egen tag_id = tag(enrolid)
	keep if tag_id==1

	*----OUTPATIENT

	merge 1:m enrolid using "$BULK/ccaeo200`i'.dta",
	drop if _merge==2
	drop if _merge==1

	keep  enrolid proc1 dx* svcdate stdplac
	keep if dx1~=""

	tostring enrolid, gen(patient_id) force

	*----Date vars

	cap drop day
	gen day = day(svcdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1

	cap drop month
	gen month = month(svcdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1

	cap drop year
	gen year = year(svcdate)
	tostring year, replace force
	replace year ="" if year=="."

	cap drop service_begin_date 
	cap drop service_end_date 
	gen str10 service_begin_date = year + "-" + month + "-" + day
	gen str10 service_end_date = service_begin_date

	replace service_begin_date = "" if year==""
	replace service_end_date = "" if year==""

	replace service_begin_date = "" if service_begin_date =="--"
	replace service_end_date = "" if service_end_date =="--"

	cap drop day month year svcdate

	*----ICD vars
	
	forvalues j=1(1)2{
		rename dx`j' icd_cd_`j'
	}

	forvalues j=3(1)5{
		gen str1 icd_cd_`j' = ""
	}
	
	forvalues j=1(1)5{
		cap drop icd_version_`j'
		gen str1 icd_version_`j' = "9" if icd_cd_`j'~=""
	}
	


	tostring stdplac, force replace
	replace stdplac="" if stdplac=="."

	rename stdplac service_place
	rename proc1 procedure_code

	*create temp file for appending later
	save "$BULK/ACG/temp_out_dx_200`i'.dta", replace



	*----INPATIENT

	use "$BULK/ccaee200`i'.dta", clear
	keep if (plank>=2500 &  plank<=2529)
	egen tot_memdays = total(memdays), by(enrolid)
	keep if tot_memdays>=300
	
	egen tag_id = tag(enrolid)
	keep if tag_id==1

	merge 1:m enrolid using "$BULK/ccaei200`i'.dta",

	tab _merge
	keep if _merge==3
	keep enrolid admdate days dx1 dx2 dx3 dx4 dx5 proc1

	tostring enrolid, gen(patient_id) force
	

	*----ICD vars

	forvalues j=1(1)5{
		rename dx`j' icd_cd_`j'
	}

	forvalues j=1(1)5{
		cap drop icd_version_`j'
		gen str1 icd_version_`j' = "9" if  icd_cd_`j'~=""
	}


	*----Date vars

	gen exitdate = admdate + days
	format exitdate %td

	*enter

	cap drop day
	gen day = day(admdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1
	
	cap drop month
	gen month = month(admdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1
	
	cap drop year
	gen year = year(admdate)
	tostring year, replace force
	replace year ="" if year=="."
	
	cap drop service_begin_date 
	gen str10 service_begin_date = year + "-" + month + "-" + day
	
	replace service_begin_date = "" if year==""
	replace service_begin_date = "" if service_begin_date =="--"
	
	cap drop day month year admdate
	
	*exit
	
	cap drop day
	gen day = day(exitdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1
	
	cap drop month
	gen month = month(exitdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1

	cap drop year
	gen year = year(exitdate)
	tostring year, replace force
	replace year ="" if year=="."
	
	cap drop service_end_date 
	gen str10 service_end_date = year + "-" + month + "-" + day
	
	replace service_end_date = "" if year==""
	replace service_end_date = "" if service_end_date =="--"
	
	cap drop day month year exitdate
	
	gen str2 service_place = "21"	
	rename proc1 procedure_code
		
	*----add outpatient diagnoses back in	
	append using "$BULK/ACG/temp_out_dx_200`i'.dta"



	*----Other Vars, to match required formatting


	gen str1 Provider_ID = ""
	gen str1 Provider_Specialty = ""
	gen str1 Provider_Specialty_NPI = ""
	gen str1 revenue_code = ""
	gen str1 Revenue_code_type = ""
	gen str1 Procedure_code_type = ""

	order patient_id icd_version_1 icd_cd_1 icd_version_2 icd_cd_2 icd_version_3 icd_cd_3 icd_version_4 icd_cd_4 icd_version_5 icd_cd_5 /*
	 */ service_begin_date service_end_date Provider_ID Provider_Specialty Provider_Specialty_NPI /*
	 */ service_place revenue_code procedure_code Revenue_code_type Procedure_code_type 

	keep patient_id icd_version_1 icd_cd_1 icd_version_2 icd_cd_2 icd_version_3 icd_cd_3 icd_version_4 icd_cd_4 icd_version_5 icd_cd_5 /*
	 */ service_begin_date service_end_date Provider_ID Provider_Specialty Provider_Specialty_NPI /*
	 */ service_place revenue_code procedure_code Revenue_code_type Procedure_code_type

	outsheet using "$BULK/ACG/Medical_0`i'.txt", nolabel noquote replace
	
}


set more off
forvalues i=5(1)6{


	use "$BULK/ccaee200`i'.dta", clear
	keep if (plank>=2500 &  plank<=2529)
	egen tot_memdays = total(memdays), by(enrolid)
	keep if tot_memdays>=300
	
	egen tag_id = tag(enrolid)
	keep if tag_id==1

	*----OUTPATIENT

	merge 1:m enrolid using "$BULK/ccaeo200`i'a.dta",
	drop if _merge==2
	drop if _merge==1

	keep  enrolid proc1 dx* svcdate stdplac
	keep if dx1~=""

	tostring enrolid, gen(patient_id) force

	*----Date vars

	cap drop day
	gen day = day(svcdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1

	cap drop month
	gen month = month(svcdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1

	cap drop year
	gen year = year(svcdate)
	tostring year, replace force
	replace year ="" if year=="."

	cap drop service_begin_date 
	cap drop service_end_date 
	gen str10 service_begin_date = year + "-" + month + "-" + day
	gen str10 service_end_date = service_begin_date

	replace service_begin_date = "" if year==""
	replace service_end_date = "" if year==""

	replace service_begin_date = "" if service_begin_date =="--"
	replace service_end_date = "" if service_end_date =="--"

	cap drop day month year svcdate

	*----ICD vars
	
	forvalues j=1(1)2{
		rename dx`j' icd_cd_`j'
	}

	forvalues j=3(1)5{
		gen str1 icd_cd_`j' = ""
	}
	
	forvalues j=1(1)5{
		cap drop icd_version_`j'
		gen str1 icd_version_`j' = "9" if icd_cd_`j'~=""
	}
	


	tostring stdplac, force replace
	replace stdplac="" if stdplac=="."

	rename stdplac service_place
	rename proc1 procedure_code

	*create temp file for appending later
	save "$BULK/ACG/temp_out_dx_200`i'.dta", replace



	*----INPATIENT

	use "$BULK/ccaee200`i'.dta", clear
	keep if (plank>=2500 &  plank<=2529)
	egen tot_memdays = total(memdays), by(enrolid)
	keep if tot_memdays>=300
	
	egen tag_id = tag(enrolid)
	keep if tag_id==1

	merge 1:m enrolid using "$BULK/ccaei200`i'.dta",

	tab _merge
	keep if _merge==3
	keep enrolid admdate days dx1 dx2 dx3 dx4 dx5 proc1

	tostring enrolid, gen(patient_id) force
	

	*----ICD vars

	forvalues j=1(1)5{
		rename dx`j' icd_cd_`j'
	}

	forvalues j=1(1)5{
		cap drop icd_version_`j'
		gen str1 icd_version_`j' = "9" if  icd_cd_`j'~=""
	}


	*----Date vars

	gen exitdate = admdate + days
	format exitdate %td

	*enter

	cap drop day
	gen day = day(admdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1
	
	cap drop month
	gen month = month(admdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1
	
	cap drop year
	gen year = year(admdate)
	tostring year, replace force
	replace year ="" if year=="."
	
	cap drop service_begin_date 
	gen str10 service_begin_date = year + "-" + month + "-" + day
	
	replace service_begin_date = "" if year==""
	replace service_begin_date = "" if service_begin_date =="--"
	
	cap drop day month year admdate
	
	*exit
	
	cap drop day
	gen day = day(exitdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1
	
	cap drop month
	gen month = month(exitdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1

	cap drop year
	gen year = year(exitdate)
	tostring year, replace force
	replace year ="" if year=="."
	
	cap drop service_end_date 
	gen str10 service_end_date = year + "-" + month + "-" + day
	
	replace service_end_date = "" if year==""
	replace service_end_date = "" if service_end_date =="--"
	
	cap drop day month year exitdate
	
	gen str2 service_place = "21"	
	rename proc1 procedure_code
		
	*----add outpatient diagnoses back in	
	append using "$BULK/ACG/temp_out_dx_200`i'.dta"



	*----Other Vars, to match required formatting


	gen str1 Provider_ID = ""
	gen str1 Provider_Specialty = ""
	gen str1 Provider_Specialty_NPI = ""
	gen str1 revenue_code = ""
	gen str1 Revenue_code_type = ""
	gen str1 Procedure_code_type = ""

	order patient_id icd_version_1 icd_cd_1 icd_version_2 icd_cd_2 icd_version_3 icd_cd_3 icd_version_4 icd_cd_4 icd_version_5 icd_cd_5 /*
	 */ service_begin_date service_end_date Provider_ID Provider_Specialty Provider_Specialty_NPI /*
	 */ service_place revenue_code procedure_code Revenue_code_type Procedure_code_type 

	keep patient_id icd_version_1 icd_cd_1 icd_version_2 icd_cd_2 icd_version_3 icd_cd_3 icd_version_4 icd_cd_4 icd_version_5 icd_cd_5 /*
	 */ service_begin_date service_end_date Provider_ID Provider_Specialty Provider_Specialty_NPI /*
	 */ service_place revenue_code procedure_code Revenue_code_type Procedure_code_type

	outsheet using "$BULK/ACG/Medical_0`i'.txt", nolabel noquote replace
	
}


set more off
forvalues i=7(1)7{


	use "$BULK/ccaea200`i'.dta", clear
	keep if (plank_a>=2500 &  plank_a<=2540)
	keep if memdays>=300
	
	*drop ppl who switch midyear
	drop if plank_a~=plank_b
	rename plank_a plank
	drop plank_b
	
	egen tag_id = tag(enrolid)
	keep if tag_id==1

	*----OUTPATIENT

	merge 1:m enrolid using "$BULK/ccaeo200`i'a.dta",
	drop if _merge==2
	drop if _merge==1

	keep  enrolid proc1 dx* svcdate stdplac
	keep if dx1~=""

	tostring enrolid, gen(patient_id) force

	*----Date vars

	cap drop day
	gen day = day(svcdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1

	cap drop month
	gen month = month(svcdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1

	cap drop year
	gen year = year(svcdate)
	tostring year, replace force
	replace year ="" if year=="."

	cap drop service_begin_date 
	cap drop service_end_date 
	gen str10 service_begin_date = year + "-" + month + "-" + day
	gen str10 service_end_date = service_begin_date

	replace service_begin_date = "" if year==""
	replace service_end_date = "" if year==""

	replace service_begin_date = "" if service_begin_date =="--"
	replace service_end_date = "" if service_end_date =="--"

	cap drop day month year svcdate

	*----ICD vars
	
	forvalues j=1(1)2{
		rename dx`j' icd_cd_`j'
	}

	forvalues j=3(1)5{
		gen str1 icd_cd_`j' = ""
	}
	
	forvalues j=1(1)5{
		cap drop icd_version_`j'
		gen str1 icd_version_`j' = "9" if icd_cd_`j'~=""
	}
	


	tostring stdplac, force replace
	replace stdplac="" if stdplac=="."

	rename stdplac service_place
	rename proc1 procedure_code

	*create temp file for appending later
	save "$BULK/ACG/temp_out_dx_200`i'.dta", replace



	*----INPATIENT

	use "$BULK/ccaea200`i'.dta", clear
	keep if (plank_a>=2500 &  plank_a<=2531)
	keep if memdays>=300
	
	*drop ppl who switch midyear
	drop if plank_a~=plank_b
	rename plank_a plank
	drop plank_b
	
	egen tag_id = tag(enrolid)
	keep if tag_id==1

	merge 1:m enrolid using "$BULK/ccaei200`i'.dta",

	tab _merge
	keep if _merge==3
	keep enrolid admdate days dx1 dx2 dx3 dx4 dx5 proc1

	tostring enrolid, gen(patient_id) force
	

	*----ICD vars

	forvalues j=1(1)5{
		rename dx`j' icd_cd_`j'
	}

	forvalues j=1(1)5{
		cap drop icd_version_`j'
		gen str1 icd_version_`j' = "9" if  icd_cd_`j'~=""
	}


	*----Date vars

	gen exitdate = admdate + days
	format exitdate %td

	*enter

	cap drop day
	gen day = day(admdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1
	
	cap drop month
	gen month = month(admdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1
	
	cap drop year
	gen year = year(admdate)
	tostring year, replace force
	replace year ="" if year=="."
	
	cap drop service_begin_date 
	gen str10 service_begin_date = year + "-" + month + "-" + day
	
	replace service_begin_date = "" if year==""
	replace service_begin_date = "" if service_begin_date =="--"
	
	cap drop day month year admdate
	
	*exit
	
	cap drop day
	gen day = day(exitdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1
	
	cap drop month
	gen month = month(exitdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1

	cap drop year
	gen year = year(exitdate)
	tostring year, replace force
	replace year ="" if year=="."
	
	cap drop service_end_date 
	gen str10 service_end_date = year + "-" + month + "-" + day
	
	replace service_end_date = "" if year==""
	replace service_end_date = "" if service_end_date =="--"
	
	cap drop day month year exitdate
	
	gen str2 service_place = "21"	
	rename proc1 procedure_code
		
	*----add outpatient diagnoses back in	
	append using "$BULK/ACG/temp_out_dx_200`i'.dta"



	*----Other Vars, to match required formatting


	gen str1 Provider_ID = ""
	gen str1 Provider_Specialty = ""
	gen str1 Provider_Specialty_NPI = ""
	gen str1 revenue_code = ""
	gen str1 Revenue_code_type = ""
	gen str1 Procedure_code_type = ""

	order patient_id icd_version_1 icd_cd_1 icd_version_2 icd_cd_2 icd_version_3 icd_cd_3 icd_version_4 icd_cd_4 icd_version_5 icd_cd_5 /*
	 */ service_begin_date service_end_date Provider_ID Provider_Specialty Provider_Specialty_NPI /*
	 */ service_place revenue_code procedure_code Revenue_code_type Procedure_code_type 

	keep patient_id icd_version_1 icd_cd_1 icd_version_2 icd_cd_2 icd_version_3 icd_cd_3 icd_version_4 icd_cd_4 icd_version_5 icd_cd_5 /*
	 */ service_begin_date service_end_date Provider_ID Provider_Specialty Provider_Specialty_NPI /*
	 */ service_place revenue_code procedure_code Revenue_code_type Procedure_code_type

	outsheet using "$BULK/ACG/Medical_0`i'.txt", nolabel noquote replace
	
}


*----
*----Make Pharma table

set more off
forvalues i=3(1)6{


	use "$BULK/ccaee200`i'.dta", clear
	keep if (plank>=2500 &  plank<=2531)
	egen tot_memdays = total(memdays), by(enrolid)
	keep if tot_memdays>=300
	
	egen tag_id = tag(enrolid)
	keep if tag_id==1

	merge 1:m enrolid using "$BULK/ccaed200`i'.dta",
	drop if _merge==2
	drop if _merge==1

	*drop unmatched enrollees
	drop if ndc==""

	keep enrolid svcdate ndcnum

	tostring enrolid, gen(patient_id) force
	cap drop enrolid

	gen str1 rx_code_type = "N"
	rename ndcnum rx_code

	*----Date vars

	cap drop day
	gen day = day(svcdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1
	
	cap drop month
	gen month = month(svcdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1
	
	cap drop year
	gen year = year(svcdate)
	tostring year, replace force
	replace year ="" if year=="."
	
	cap drop rx_fill_date
	gen str10 rx_fill_date = year + "-" + month + "-" + day

	replace rx_fill_date = "" if year==""
	replace rx_fill_date = "" if rx_fill_date =="--"

	cap drop day month year svcdate
	
	gen str1 Rx_days_supply = ""
	order patient_id rx_fill_date rx_code rx_code_type Rx_days_supply
	
	outsheet using "$BULK/ACG/Drug_0`i'.txt", nolabel noquote replace
	
}


set more off
forvalues i=7(1)7{


	use "$BULK/ccaea200`i'.dta", clear
	keep if (plank_a>=2500 &  plank_a<=2540)
	keep if memdays>=300
	
	*drop ppl who switch midyear
	drop if plank_a~=plank_b
	rename plank_a plank
	drop plank_b

	egen tag_id = tag(enrolid)
	keep if tag_id==1

	merge 1:m enrolid using "$BULK/ccaed200`i'.dta",
	drop if _merge==2
	drop if _merge==1

	*drop unmatched enrollees
	drop if ndc==""

	keep enrolid svcdate ndcnum

	tostring enrolid, gen(patient_id) force
	cap drop enrolid

	gen str1 rx_code_type = "N"
	rename ndcnum rx_code

	*----Date vars

	cap drop day
	gen day = day(svcdate)
	tostring day, replace force
	replace day ="" if day=="."
	replace day ="0"+day if length(day)==1
	
	cap drop month
	gen month = month(svcdate)
	tostring month, replace force
	replace month ="" if month=="."
	replace month ="0"+month if length(month)==1
	
	cap drop year
	gen year = year(svcdate)
	tostring year, replace force
	replace year ="" if year=="."
	
	cap drop rx_fill_date
	gen str10 rx_fill_date = year + "-" + month + "-" + day

	replace rx_fill_date = "" if year==""
	replace rx_fill_date = "" if rx_fill_date =="--"

	cap drop day month year svcdate
	
	gen str1 Rx_days_supply = ""
	order patient_id rx_fill_date rx_code rx_code_type Rx_days_supply
	
	outsheet using "$BULK/ACG/Drug_0`i'.txt", nolabel noquote replace
	
}


/*

//program to create acg files
//Run just once
//Run from shell, from age3 server
//might need to do something like "chmod 755 <filename>" to make it executable


#!/bin/sh

cd /usr/local/acg/jhuacg9.0/

jhuacg -new-acg-file "/disk/agebulk2/medstat.work/gerusom/ACG/ACG_2003.acgd"  -patient "/disk/agebulk2/medstat.work/gerusom/ACG/Patient_03.txt" -patient-format tab -patient-skip -medical "/disk/agebulk2/medstat.work/gerusom/ACG/Medical_03.txt" -medical-format tab -medical-skip -pharmacy "/disk/agebulk2/medstat.work/gerusom/ACG/Drug_03.txt" -pharmacy-format tab -pharmacy-skip -all-models
echo "Complete 2003 ACG build"
jhuacg -new-acg-file "/disk/agebulk2/medstat.work/gerusom/ACG/ACG_2004.acgd"  -patient "/disk/agebulk2/medstat.work/gerusom/ACG/Patient_04.txt" -patient-format tab -patient-skip -medical "/disk/agebulk2/medstat.work/gerusom/ACG/Medical_04.txt" -medical-format tab -medical-skip -pharmacy "/disk/agebulk2/medstat.work/gerusom/ACG/Drug_04.txt" -pharmacy-format tab -pharmacy-skip -all-models
echo "Complete 2004 ACG build"
jhuacg -new-acg-file "/disk/agebulk2/medstat.work/gerusom/ACG/ACG_2005.acgd"  -patient "/disk/agebulk2/medstat.work/gerusom/ACG/Patient_05.txt" -patient-format tab -patient-skip -medical "/disk/agebulk2/medstat.work/gerusom/ACG/Medical_05.txt" -medical-format tab -medical-skip -pharmacy "/disk/agebulk2/medstat.work/gerusom/ACG/Drug_05.txt" -pharmacy-format tab -pharmacy-skip -all-models
echo "Complete 2005 ACG build"
jhuacg -new-acg-file "/disk/agebulk2/medstat.work/gerusom/ACG/ACG_2006.acgd"  -patient "/disk/agebulk2/medstat.work/gerusom/ACG/Patient_06.txt" -patient-format tab -patient-skip -medical "/disk/agebulk2/medstat.work/gerusom/ACG/Medical_06.txt" -medical-format tab -medical-skip -pharmacy "/disk/agebulk2/medstat.work/gerusom/ACG/Drug_06.txt" -pharmacy-format tab -pharmacy-skip -all-models
echo "Complete 2006 ACG build"


jhuacg -export models -acg-file "/disk/agebulk2/medstat.work/gerusom/ACG/ACG_2003.acgd" -export-file "/disk/agebulk2/medstat.work/gerusom/ACG/Pred_2003.txt" -delim tab
echo "Complete 2003 export"
jhuacg -export models -acg-file "/disk/agebulk2/medstat.work/gerusom/ACG/ACG_2004.acgd" -export-file "/disk/agebulk2/medstat.work/gerusom/ACG/Pred_2004.txt" -delim tab
echo "Complete 2004 export"
jhuacg -export models -acg-file "/disk/agebulk2/medstat.work/gerusom/ACG/ACG_2005.acgd" -export-file "/disk/agebulk2/medstat.work/gerusom/ACG/Pred_2005.txt" -delim tab
echo "Complete 2005 export"
jhuacg -export models -acg-file "/disk/agebulk2/medstat.work/gerusom/ACG/ACG_2006.acgd" -export-file "/disk/agebulk2/medstat.work/gerusom/ACG/Pred_2006.txt" -delim tab
echo "Complete 2006 export"


*/

*--Finally, convert predictions to more easily mergeable form

forvalues i=3(1)6{

	local next = `i' + 1

	insheet using "$BULK/ACG/Pred_200`i'.txt", tab clear case
	keep patient_id dxrxpm_ttcost_l_tt_prir dxrxpm_rxcost_l_rx_prir dxpm_ttcost_l_tt_prir rxpm_rxcost_l_rx_prir

	rename dxrxpm_ttcost_l_tt_prir pred_dxrx_l_tot_200`next'
	rename dxrxpm_rxcost_l_rx_prir pred_dxrx_l_pharm_200`next'
	rename dxpm_ttcost_l_tt_prir   pred_dx_l_tot_200`next'
	rename rxpm_rxcost_l_rx_prir   pred_rx_l_pharm_200`next'
	
	tostring patient_id, force replace

	save "$BULK/ACG/Pred_200`i'.dta", replace

}



