


/*
This do file makes:


Tables
- summ cost/plan choice stats
- main results
- robustness: no residual corr between age and cost
- mechanism: inertia and variance

Figures
-distribution of ln spending
-lpolys by age, by gender, using alt cost vars

*/


*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
* Load data 
*----------------------------------------------------
*----------------------------------------------------


clear
clear mata
clear matrix
*set mem 6g
set more off

global SOURCE "/disk/aging/medstat/data/sas"
global BULK "/disk/agebulk2/medstat.work/gerusom"
global WORK "/disk/agedisk3/medstat.work/gerusom"
global SCRATCH "/disk/agescratch4/gerusom"

use "$WORK/Data/Main_2016.dta", clear


*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
* Define sample
*----------------------------------------------------
*----------------------------------------------------

//singles with adequate panel and vars

global CONTROLS = "union hourly ft"

cap drop sample
areg ln_predtot chooseB totpay $CONTROLS1 I_ag2_2 I_ag2_3 I_ag2_4 if emprel==1 & count_fam==1 & year>=2005 & year<=2007 & ag2>=1 & ag2<=4, a(egeoloc)
generate sample = e(sample)


*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
* Addtl Vars
*----------------------------------------------------
*----------------------------------------------------


local ided_L = 500
local ided_H = 300
local coins_L = .2
local coins_H = .1
local ioop_L = 4250
local ioop_H	= 2300

foreach plan in L H{

	cap drop EOOP2_`plan'
	gen EOOP2_`plan' = predtot if predtot<`ided_`plan'' & sample==1
	replace EOOP2_`plan' = (predtot - `ided_`plan'')*`coins_`plan'' + `ided_`plan'' if predtot>=`ided_`plan'' & sample==1
	replace EOOP2_`plan' = `ioop_`plan'' if EOOP2_`plan'>`ioop_`plan'' & EOOP2_`plan' ~=. & sample==1
	label var EOOP2_`plan' "OOP of expected non-drug costs in `plan'"
	
	cap drop ci`plan'
	gen ci`plan' = predtot - EOOP2_`plan'
	label var ci`plan' "employer share of expected costs; ignore concavity of cost sharing"	
}

gen MCDeltaPlan = ciH-ciL
gen ln_MCDeltaPlan = ln(100 + MCDeltaPlan)

*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
* Table 2 Summary statistics of totpay and plan choice
*----------------------------------------------------
*----------------------------------------------------

matrix A = J(9,5,.)

	quiet summ chooseB if sample==1
	matrix A[1,1] = r(mean)*100
	matrix A[1,5] = r(N)
	quiet summ totpay if sample==1
	matrix A[1,2] = r(mean)
	quiet summ totpay if sample==1 & chooseB==0
	matrix A[1,3] = r(mean)
	quiet summ totpay if sample==1 & chooseB==1
	matrix A[1,4] = r(mean)
	
scalar row = 2

forvalues i=1(1)4{

	scalar row = row + 1
	
	quiet summ chooseB if sample==1 & ag2==`i'
	matrix A[row,1] = r(mean)*100
	matrix A[row,5] = r(N)
	quiet summ totpay if sample==1 & ag2==`i'
	matrix A[row,2] = r(mean)
	quiet summ totpay if sample==1 & chooseB==0 & ag2==`i'
	matrix A[row,3] = r(mean)
	quiet summ totpay if sample==1 & chooseB==1 & ag2==`i'
	matrix A[row,4] = r(mean)

}

scalar row = 7

forvalues i=0(1)1{

	scalar row = row + 1
	
	quiet summ chooseB if sample==1 & fem==`i'
	matrix A[row,1] = r(mean)*100
	matrix A[row,5] = r(N)
	quiet summ totpay if sample==1 & fem==`i'
	matrix A[row,2] = r(mean)
	quiet summ totpay if sample==1 & chooseB==0 & fem==`i'
	matrix A[row,3] = r(mean)
	quiet summ totpay if sample==1 & chooseB==1 & fem==`i'
	matrix A[row,4] = r(mean)

}

matrix rownames A = "overall" "by_age" "18-29" "30-39" "40-49" "50-59" "by_gender" "men" "women" 
matrix colnames A =  "chooseH" "All_enrollees" "PlanL_enrollees" "PlanH_enrollees" "obs"
matrix list A

//outtable using "$WORK/Results2016/summstats", mat(A) replace nobox center clabel("usesumm") caption("Plan_selection_and_costs_by_demographics_2005-2007") format(%9.0fc)
*sxml_tab A, save("$WORK`c(dirsep)'Results2016`c(dirsep)'Tables`c(dirsep)'summstats") replace

*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
* Table 3 Regression versions of the choice vs. risk plots
*----------------------------------------------------
*----------------------------------------------------

	qui su chooseB if sample==1
	local mean = r(mean)

	quiet reg chooseB ln_predtot I_ag2_2-I_ag2_4 fem if sample==1, cluster(enrolid)
	est sto a1
	estadd local mean = `mean'	
	
	quiet reg chooseB ln_predtot I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1, cluster(enrolid)
	est sto a2
	estadd local mean = `mean'
		
	quiet areg chooseB ln_predtot I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1, cluster(enrolid) absorb(egeoloc)
	est sto a3
	estadd local mean = `mean'
	
	quiet areg chooseB ln_predtot I_ag2_2-I_ag2_4  $CONTROLS if sample==1, cluster(enrolid) absorb(egeoloc)
	est sto a4
	estadd local mean = `mean'
		
	quiet areg chooseB ln_predtot fem $CONTROLS if sample==1, cluster(enrolid) absorb(egeoloc)
	est sto a5
	estadd local mean = `mean'
		
	quiet areg chooseB ln_totpay I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1, cluster(enrolid) absorb(egeoloc)
	est sto b4
	
	quiet areg chooseB ln_last_totpay I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1, cluster(enrolid) absorb(egeoloc)
	est sto b5

	quiet areg chooseB I_ag2_2-I_ag2_4 I_ag2_1_ln_predtot-I_ag2_4_ln_predtot fem $CONTROLS if sample==1, cluster(enrolid) absorb(egeoloc)
	est sto b6

	quiet areg chooseB ln_predtot I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1, cluster(enrolid) absorb(egeoloc)
	est sto c3
	estadd local mean = `mean'
	
	quiet areg chooseB ln_predtot I_ag2_2-I_ag2_4  $CONTROLS if sample==1, cluster(enrolid) absorb(egeoloc)
	est sto c4
	estadd local mean = `mean'

	esttab a1 a2 a3 a4 a5 using "$WORK`c(dirsep)'Results2016`c(dirsep)'Tables`c(dirsep)'Main.xls", ///
	se lines replace b(%9.3fc) se(%9.3fc) nostar ///
	tab nopar ///
	keep(ln_predtot I_ag2_2 I_ag2_3 I_ag2_4 fem) order(ln_predtot I_ag2_2 I_ag2_3 I_ag2_4 fem) ///
	stats(mean N, fmt(%9.3fc))

	esttab c3 c4 b4 b5 b6 using "$WORK`c(dirsep)'Results2016`c(dirsep)'Tables`c(dirsep)'MainExtended.xls", ///
	se lines replace b(%9.3fc) se(%9.3fc) ///
	tab nopar ///
	keep(ln_predtot ln_totpay ln_last_totpay I_ag2_2 I_ag2_3 I_ag2_4 I_ag2_1_ln_predtot I_ag2_2_ln_predtot I_ag2_3_ln_predtot  I_ag2_4_ln_predtot fem) ///
	order(ln_predtot ln_totpay ln_last_totpay I_ag2_2 I_ag2_3 I_ag2_4 I_ag2_1_ln_predtot I_ag2_2_ln_predtot I_ag2_3_ln_predtot  I_ag2_4_ln_predtot fem) ///
	stats(N, fmt(%9.0fc))		




*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
*----------------------------------------------------
* Table 4: robustness: no residual corr between age and cost
*----------------------------------------------------
*----------------------------------------------------

	quiet reg totpay predtot if sample==1, cluster(enrolid)
	est sto reg2
	quiet reg totpay predtot I_ag2_2-I_ag2_4 if sample==1, cluster(enrolid)
	est sto reg3
	test I_ag2_2 I_ag2_3 I_ag2_4
	local fstat = r(F)
	local pval = r(p)
	estadd local Fstat = `fstat'
	estadd local Pval = `pval'
	
	quiet reg totpay predtot  if sample==1 & ag2==1,r cluster(enrolid)
	est sto reg4
	quiet reg totpay predtot  if sample==1 & ag2==2,r cluster(enrolid)
	est sto reg5
	quiet reg totpay predtot  if sample==1 & ag2==3,r cluster(enrolid)
	est sto reg6
	quiet reg totpay predtot  if sample==1 & ag2==4,r cluster(enrolid)
	est sto reg7
	quiet reg totpay predtot B_last if sample==1, cluster(enrolid)
	est sto reg8

	
	esttab reg2 reg3 reg4 reg5 reg6 reg7 reg8 using "$WORK`c(dirsep)'Results2016`c(dirsep)'Tables`c(dirsep)'ACGfit.xls", ///
	se lines replace b(%9.3fc) se(%9.3fc) ///
	tab nopar ///
	keep(predtot _cons I_ag2_2 I_ag2_3 I_ag2_4) order(predtot _cons I_ag2_2 I_ag2_3 I_ag2_4) nostar ///
	stats(Fstat Pval N r2, fmt(%9.0fc %9.2fc))			
	

*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
* Table 5: Mechanisms Inertia / Variance / Heuristics
*----------------------------------------------------
*----------------------------------------------------
cap drop scale*
gen scaleerror = error/1000000
gen scaleerrorsq = errorsq/10000000000000

//Original 

	qui su chooseB if sample==1
	local mean1 = r(mean)

	quiet areg chooseB ln_predtot I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1 , cluster(enrolid) absorb(egeoloc)
	est sto a1
	estadd local mean = `mean1'

//Variance

	quiet areg chooseB scaleerror ln_predtot I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1 , cluster(enrolid) absorb(egeoloc)
	est sto a2
	estadd local mean = `mean1'


	quiet areg chooseB scaleerrorsq ln_predtot I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1 , cluster(enrolid) absorb(egeoloc)
	est sto a3
	estadd local mean = `mean1'
	
//Perfect Foresight 

	qui su chooseB if sample==1 & ln_totpay ~=.
	local mean1 = r(mean)

	qui su chooseB if sample==1 & ln_transtotpay ~=.
	local mean2 = r(mean)

	quiet areg chooseB ln_totpay I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1 , cluster(enrolid) absorb(egeoloc)
	est sto b1
	estadd local mean = `mean1'
	
	quiet areg chooseB ln_transtotpay I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1 , cluster(enrolid) absorb(egeoloc)
	est sto b2
	estadd local mean = `mean2'
	

//Heuristics

	qui su chooseB if sample==1 & ln_last_totpay ~=.
	local mean1 = r(mean)

	qui su chooseB if sample==1 & ln_last_transtotpay ~=.
	local mean2 = r(mean)

	quiet areg chooseB ln_last_totpay I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1 , cluster(enrolid) absorb(egeoloc)
	est sto b3
	estadd local mean = `mean1'

	quiet areg chooseB ln_last_transtotpay I_ag2_2-I_ag2_4 fem $CONTROLS if sample==1 , cluster(enrolid) absorb(egeoloc)
	est sto b4
	estadd local mean = `mean2'
	

//Inertia

	// first years won't be in the sample because no predicted spending. Need firstyear sample
	cap drop firstyearsample
	gen firstyearsample  = firstyear==1 & emprel==1 & count_fam==1 & year>=2005 & year<=2007 & ag2>=1 & ag2<=4

	qui su chooseB if firstyearsample ==1 & ln_totpay ~=.
	local mean1 = r(mean)

	qui su chooseB if firstyearsample ==1 & ln_transtotpay ~=.
	local mean2 = r(mean)
		
	quiet areg chooseB ln_totpay I_ag2_2-I_ag2_4 fem $CONTROLS if firstyearsample==1 , cluster(enrolid) absorb(egeoloc)
	est sto b5
	estadd local mean = `mean1'

	quiet areg chooseB ln_transtotpay I_ag2_2-I_ag2_4 fem $CONTROLS if firstyearsample==1 , cluster(enrolid) absorb(egeoloc)
	est sto b6
	estadd local mean = `mean2'


	esttab a1 a2 a3 b1 b2 b3 b4 b5 b6 using "$WORK`c(dirsep)'Results2016`c(dirsep)'Tables`c(dirsep)'mechAll.xls", ///
	se lines replace b(%9.3fc) se(%9.3fc) nostar ///
	tab nopar ///
	keep(ln_predtot ln_totpay ln_transtotpay ln_last_totpay ln_last_transtotpay I_ag2_2 I_ag2_3 I_ag2_4 scaleerror scaleerrorsq fem) ///
	order(ln_predtot ln_totpay ln_transtotpay ln_last_totpay ln_last_transtotpay I_ag2_2 I_ag2_3 I_ag2_4 scaleerror scaleerrorsq fem) ///
	stats(mean N r2, fmt(%9.0fc %9.2fc))	


*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
* Figure 5: Distributions of Spending
*----------------------------------------------------
*----------------------------------------------------		

cap drop nouse
gen nouse = (totpay==0)

*----PDF by age
cap drop sample
gen sample=1 if year>=2005 & year<=2007 & count_fam==1
matrix A = J(2,8,.)
forvalues a=1(1)4{
	scalar col1 = 2*`a' - 1
	scalar col2 = 2*`a'
	quiet summ nouse if ag2==`a' & sample==1
	matrix A[1, col1] = `a'
	matrix A[2, col1] = `a'
	matrix A[1, col2] = 0
	matrix A[2, col2] = r(mean)
	
}
matrix list A
cap drop A*
svmat A
twoway (scatter A2 A1 in 1/2, lcolor(maroon) connect(l) lpattern(solid) msymbol(none) lwidth(thick) ) /*
 */ (scatter A4 A3 in 1/2, lcolor(dkorange) connect(l) lpattern(dash) msymbol(none) lwidth(thick)) /*
 */ (scatter A6 A5 in 1/2, connect(l) lpattern(dash_dot) msymbol(none) lwidth(thick)) /*
 */ (scatter A8 A7 in 1/2, lcolor(gs10) connect(l) lpattern(shortdash) msymbol(none) lwidth (thick)), /*
 */ graphregion(color(white)) bgcolor(white) /*
 */ ytitle("") /*
 */ xlabel( 1 " " 2 " " 3 " " 4 " ") /*
 */ xtitle("Pr(no claims)") /*
 */ legend(/*label(1 "18-29") label(2 "30-39") label(3 "40-49") label(4 "50-59")*/ label(5 " ") label(8 " ") order(5 6 7 8) row(2) region(lcolor(white))) /*
 */  saving(zero, replace) fxsize(50) nodraw
 
twoway (kdensity ln_totpay if ag2==1 & totpay<100000 & ln_totpay>2 & sample==1, lcolor(maroon) lpattern(solid)) /*
 */ (kdensity ln_totpay if ag2==2 & totpay<100000 & ln_totpay>2 & sample==1, lcolor(dkorange) lpattern(dash)) /*
 */ (kdensity ln_totpay if ag2==3 & totpay<100000 & ln_totpay>2 & sample==1, lpattern(dash_dot)) /*
 */ (kdensity ln_totpay if ag2==4 & totpay<100000 & ln_totpay>2 & sample==1, lcolor(gs10) lpattern(shortdash)), /*
 */ graphregion(color(white)) bgcolor(white) /*
 */ ytitle("") ylabel(0 "") /*
  */ xlabel(3.0 "$20" 4.61 "$100" 6.21 "$500" 7.82 "$2,500" 9.43 "$12.5k" 11.04 "$62.5k")  /*
 */ xtitle("claims, conditional on >0") /*
 */ legend(label(1 "18-29") label(2 "30-39") label(3 "40-49") label(4 "50-59") row(2)) /*
 */  saving(pdf, replace) fxsize(150) nodraw
 
graph combine zero.gph pdf.gph, row(1) /*
 */ graphregion(color(white)) 
 
graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'PDF_single_2005-2007.eps", replace
graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'PDF_single_2005-2007.pdf", replace

 

*----PDF by sex
cap drop sample
gen sample=1 if year>=2005 & year<=2007 & count_fam==1
matrix A = J(2,8,.)
forvalues a=0(1)1{
	scalar col1 = 2*`a' + 1
	scalar col2 = 2*`a' + 2 
	quiet summ nouse if fem==`a' & sample==1
	matrix A[1, col1] = `a'
	matrix A[2, col1] = `a'
	matrix A[1, col2] = 0
	matrix A[2, col2] = r(mean)
	
}
matrix list A
cap drop A*
svmat A
twoway (scatter A2 A1 in 1/2, lcolor(maroon) connect(l) lpattern(solid) msymbol(none) lwidth(thick) ) /*
 */ (scatter A4 A3 in 1/2, lcolor(gs10) connect(l) lpattern(dash) msymbol(none) lwidth(thick)), /*
 */ graphregion(color(white)) bgcolor(white) /*
 */ ytitle("") /*
 */ xlabel( -.15 " " 0 " " 1 " ") /*
 */ xtitle("Pr(no claims)") /*
 */ legend(/*label(1 "18-29") label(2 "30-39") label(3 "40-49") label(4 "50-59")*/ label(5 " ") label(8 " ") order(5 6 7 8) row(1) region(lcolor(white))) /*
 */  saving(zero, replace) fxsize(50) nodraw
 
twoway (kdensity ln_totpay if fem==0 & totpay<100000 & ln_totpay>2 & sample==1, lcolor(maroon) lpattern(solid)) /*
 */ (kdensity ln_totpay if fem==1 & totpay<100000 & ln_totpay>2 & sample==1, lcolor(gs10) lpattern(dash)), /*
 */ graphregion(color(white)) bgcolor(white) /*
 */ ytitle("") ylabel(0 "")  /*
 */ xlabel(3.0 "$20" 4.61 "$100" 6.21 "$500" 7.82 "$2,500" 9.43 "$12.5k" 11.04 "$62.5k")  /*
 */ xtitle("claims, conditional on >0") /*
 */ legend(label(1 "men") label(2 "women") row(1)) /*
 */  saving(pdf, replace) fxsize(150) nodraw
 
graph combine zero.gph pdf.gph, row(1) /*
 */ graphregion(color(white)) 
 
graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'PDF_single_sex_2005-2007.eps", replace
graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'PDF_single_sex_2005-2007.pdf", replace



*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
* Figure A2: Expected costs and realized costs
*----------------------------------------------------
*----------------------------------------------------		

cap drop x45
cap drop y45
gen x45 = 6.2 in 1
replace x45 = 10.4 in 2
gen y45 = 6.2 in 1
replace y45 = 10.4 in 2

foreach age in 1 2 3 4{
	cap drop x_`age'
	cap drop y_`age'
	qui reg ln_totpay ln_predtot if sample==1 & ag2==`age', r cluster(enrolid)
	gen x_`age' =  6.2 in 1
	replace x_`age' = 10.4 in 2
	qui gen y_`age' = _b[ln_predtot]*6.2 + _b[_cons] in 1 
	replace y_`age' = _b[ln_predtot]*10.4 + _b[_cons] in 2
	
	local show = trim("`: display %10.1f _b[ln_predtot]'")
	local showf = "`show'"
	local legend`age' = `"legend(on order(- `"slope: `showf'"') bplacement(nwest) ring(0) region(lwidth(none)))"'
}



local yvar ln_totpay
local var ln_predtot

	foreach var2 in `var' `yvar'{
	
			quiet summ `var2' if sample==1 & ag2==1, d
			scalar `var2'min_1 = r(p1)
			scalar `var2'max_1 = r(p99)
			
			quiet summ `var2' if sample==1 & ag2==2, d
			scalar `var2'min_2 = r(p1)
			scalar `var2'max_2 = r(p99)
			
			quiet summ `var2' if sample==1 & ag2==3, d
			scalar `var2'min_3 = r(p1)
			scalar `var2'max_3 = r(p99)
		
			quiet summ `var2' if sample==1 & ag2==4, d
			scalar `var2'min_4 = r(p1)
			scalar `var2'max_4 = r(p99)
	}


foreach age in 1 2 3 4{
		
			twoway (scatter `yvar' `var' if ag2==`age' & sample==1 & `var'>=`var'min_`age' & `var'<`var'max_`age' & `yvar'>=`yvar'min_`age' & `yvar'<`yvar'max_`age' , msize(vtiny) ) ///
		 	 (scatter y_`age' x_`age' in 1/2, connect(direct) msymbol(none) lpattern(dash)) , ///
		 	 xtitle("expected costs") xlabel(4.83 "$125" 6.2 "$500" 7.6 "$2k" 8.99 "$8k" 10.37 "$32k" , grid)  ///
		 	 ytitle("realized costs") ylabel(3.4 "$30" 4.83 "$125" 6.2 "$500" 7.6 "$2k" 8.99 "$8k" 10.37 "$32k" , grid) ///
		 	 `legend`age'' ///
		 	 graphregion(color(white)) ///
		 	 aspectratio(1) ///
		 	 saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'spendscatter_`age'.gph", replace)

			graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'spendscatter_`age'.pdf", replace
}



*------------------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------
* Figure A3: Plan choice lpolys
*----------------------------------------------------
*----------------------------------------------------			

//MAIN BY AGE
foreach var in predtot{

			quiet summ ln_`var' if sample==1 & ag2==1, d
			scalar min_1 = r(p1)
			scalar max_1 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==2, d
			scalar min_2 = r(p1)
			scalar max_2 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==3, d
			scalar min_3 = r(p1)
			scalar max_3 = r(p99)
		
			quiet summ ln_`var' if sample==1 & ag2==4, d
			scalar min_4 = r(p1)
			scalar max_4 = r(p99)
			
			twoway (lpoly chooseB ln_`var' if ag2==1 & sample==1 & ln_`var'>=min_1 & ln_`var'<max_1 & sample==1, lcolor(maroon) lpattern(dash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==2 & sample==1 & ln_`var'>=min_2 & ln_`var'<max_2 & sample==1, lcolor(dkorange) lpattern(..-) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==3 & sample==1 & ln_`var'>=min_3 & ln_`var'<max_3 & sample==1, lpattern(shortdash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==4 & sample==1 & ln_`var'>=min_4 & ln_`var'<max_4 & sample==1, lcolor(gs10) lpattern(solid) lwidth(medthick)), /*
		 	 */ xtitle("expected costs, {it:C}{subscript:i}") xlabel(6.2 "$500" 6.9 "$1000" 7.6 "$2k" 8.29 "$4k" 8.99 "$8k" 9.68 "$16k" 10.37 "$32k", grid)  /*
		 	 */ ytitle("Chose Plan {it:H}") ylabel(.1(.1).7) /*
		 	 */ legend(label(1 "18-29") label(2 "30-39") label(3 "40-49") label(4 "50-59") row(2) ring(0) position(5) bmargin(medium)) /*
		 	 */ graphregion(color(white)) /*
		 	 */ aspectratio(1) /*
		 	 */ saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'lpolyage.gph", replace)

			graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'lpolyage.pdf", replace
}

//BY SEX 
foreach var in predtot{

			quiet summ ln_`var' if sample==1 & fem==0, d
			scalar min_1 = r(p1)
			scalar max_1 = r(p99)
			
			quiet summ ln_`var' if sample==1 & fem==1, d
			scalar min_2 = r(p1)
			scalar max_2 = r(p99)
			
			twoway (lpoly chooseB ln_`var' if fem==0 & sample==1 & ln_`var'>=min_1 & ln_`var'<max_1 & sample==1, lcolor(maroon) lpattern(dash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if fem==1 & sample==1 & ln_`var'>=min_2 & ln_`var'<max_2 & sample==1, lcolor(gs10) lpattern(solid) lwidth(medthick)), /*
		 	 */ xtitle("expected costs, {it:C}{subscript:i}") xlabel(6.2 "$500" 6.9 "$1000" 7.6 "$2k" 8.29 "$4k" 8.99 "$8k" 9.68 "$16k" 10.37 "$32k", grid)  /*
		 	 */ ytitle("Chose Plan {it:H}") ylabel(.1(.1).7) /*
		 	 */ legend(label(1 "men") label(2 "women") row(1) ring(0) position(5) bmargin(medium)) /*
		 	 */ graphregion(color(white)) /*
		 	 */ aspectratio(1) /*
		 	 */ saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'lpolysex.gph", replace)

			graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'lpolysex.pdf", replace
}

//ALT BY AGE - USING difference in plan marginal costs: ciH - ciL "ln_MCDeltaPlan"
foreach var in MCDeltaPlan{

			quiet summ ln_`var' if sample==1 & ag2==1, d
			scalar min_1 = r(p1)
			scalar max_1 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==2, d
			scalar min_2 = r(p1)
			scalar max_2 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==3, d
			scalar min_3 = r(p1)
			scalar max_3 = r(p99)
		
			quiet summ ln_`var' if sample==1 & ag2==4, d
			scalar min_4 = r(p1)
			scalar max_4 = r(p99)
			
			twoway (lpoly chooseB ln_`var' if ag2==1 & sample==1 & ln_`var'>=min_1 & ln_`var'<max_1 & sample==1, lcolor(maroon) lpattern(dash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==2 & sample==1 & ln_`var'>=min_2 & ln_`var'<max_2 & sample==1, lcolor(dkorange) lpattern(..-) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==3 & sample==1 & ln_`var'>=min_3 & ln_`var'<max_3 & sample==1, lpattern(shortdash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==4 & sample==1 & ln_`var'>=min_4 & ln_`var'<max_4 & sample==1, lcolor(gs10) lpattern(solid) lwidth(medthick)), /*
		 	 */ xtitle("inurer marginal cost difference, {it:c{sub:iH}-c{sub:iL}} ") xlabel(5.52 "$250" 6.2 "$500" 6.9 "$1000" 7.6 "$2k", grid)  /*
		 	 */ ytitle("Chose Plan {it:H}") ylabel(.1(.1).7) /*
		 	 */ legend(label(1 "18-29") label(2 "30-39") label(3 "40-49") label(4 "50-59") row(2) ring(0) position(5) bmargin(medium)) /*
		 	 */ graphregion(color(white)) /*
		 	 */ aspectratio(1) /*
		 	 */ saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'lpolyage_empCost.gph", replace)

			graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'lpolyage_empCost.pdf", replace
			
			
			quiet summ ln_`var' if sample==1 & fem==0, d
			scalar min_1 = r(p1)
			scalar max_1 = r(p99)
			
			quiet summ ln_`var' if sample==1 & fem==1, d
			scalar min_2 = r(p1)
			scalar max_2 = r(p99)
			
			twoway (lpoly chooseB ln_`var' if fem==0 & sample==1 & ln_`var'>=min_1 & ln_`var'<max_1 & sample==1, lcolor(maroon) lpattern(dash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if fem==1 & sample==1 & ln_`var'>=min_2 & ln_`var'<max_2 & sample==1, lcolor(gs10) lpattern(solid) lwidth(medthick)), /*
		 	 */ xtitle("inurer marginal cost difference, {it:c{sub:iH}-c{sub:iL}} ") xlabel(5.52 "$250" 6.2 "$500" 6.9 "$1000" 7.6 "$2k", grid)  /*
		 	 */ ytitle("Chose Plan {it:H}") ylabel(.1(.1).7) /*
		 	 */ legend(label(1 "men") label(2 "women") row(1) ring(0) position(5) bmargin(medium)) /*
		 	 */ graphregion(color(white)) /*
		 	 */ aspectratio(1) /*
		 	 */ saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'lpolysex_empCost.gph", replace)

			graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'lpolysex_empCost.pdf", replace
}


//HEURISTIC (t-1)


foreach var in last_transtotpay{
		

			quiet summ ln_`var' if sample==1 & ag2==1, d
			scalar min_1 = r(p1)
			scalar max_1 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==2, d
			scalar min_2 = r(p1)
			scalar max_2 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==3, d
			scalar min_3 = r(p1)
			scalar max_3 = r(p99)
		
			quiet summ ln_`var' if sample==1 & ag2==4, d
			scalar min_4 = r(p1)
			scalar max_4 = r(p99)
			
			twoway (lpoly chooseB ln_`var' if ag2==1 & sample==1 & ln_`var'>=min_1 & ln_`var'<max_1 & sample==1 & ln_`var'>3.9, lcolor(maroon) lpattern(dash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==2 & sample==1 & ln_`var'>=min_2 & ln_`var'<max_2 & sample==1 & ln_`var'>3.9, lcolor(dkorange) lpattern(..-) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==3 & sample==1 & ln_`var'>=min_3 & ln_`var'<max_3 & sample==1 & ln_`var'>3.9, lpattern(shortdash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==4 & sample==1 & ln_`var'>=min_4 & ln_`var'<max_4 & sample==1 & ln_`var'>3.9, lcolor(gs10) lpattern(solid) lwidth(medthick)), /*
		 	 */ xtitle("realized healthcare costs, time {it:t-1}") xlabel(4.094 "$60" 5.52 "$250" 6.9 "$1000"  8.29 "$4k" 9.68 "$16k" 11.067 "$64k", grid )  /*
		 	 */ ytitle("Chose Plan {it:H}") ylabel(.1(.1).7) /*
		 	 */ legend(off) /*
		 	 */ aspectratio(1) /*
		 	 */ graphregion(color(white)) /*
		 	 */ subtitle("zeros transformed")  saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'last1.gph", replace)

 			graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'last1.pdf", replace
}


foreach var in last_totpay{
		

			quiet summ ln_`var' if sample==1 & ag2==1, d
			scalar min_1 = r(p1)
			scalar max_1 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==2, d
			scalar min_2 = r(p1)
			scalar max_2 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==3, d
			scalar min_3 = r(p1)
			scalar max_3 = r(p99)
		
			quiet summ ln_`var' if sample==1 & ag2==4, d
			scalar min_4 = r(p1)
			scalar max_4 = r(p99)
			
			twoway (lpoly chooseB ln_`var' if ag2==1 & sample==1 & ln_`var'>=min_1 & ln_`var'<max_1 & sample==1 & ln_`var'>3.9, lcolor(maroon) lpattern(dash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==2 & sample==1 & ln_`var'>=min_2 & ln_`var'<max_2 & sample==1 & ln_`var'>3.9, lcolor(dkorange) lpattern(..-) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==3 & sample==1 & ln_`var'>=min_3 & ln_`var'<max_3 & sample==1 & ln_`var'>3.9, lpattern(shortdash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==4 & sample==1 & ln_`var'>=min_4 & ln_`var'<max_4 & sample==1 & ln_`var'>3.9, lcolor(gs10) lpattern(solid) lwidth(medthick)), /*
		 	 */ xtitle("realized healthcare costs, time {it:t-1}") xlabel(4.094 "$60" 5.52 "$250" 6.9 "$1000"  8.29 "$4k" 9.68 "$16k"  11.067 "$64k", grid)  /*
		 	 */ ytitle("Chose Plan {it:H}") ylabel(.1(.1).7) /*
		 	 */ legend(off) /*
		 	 */ aspectratio(1) /*
		 	 */ graphregion(color(white)) /*
		 	 */ subtitle("zeros dropped")  saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'last2.gph", replace)
		 	 
 			graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'last2.pdf", replace
}


//PERFECT FORESIGHT


foreach var in transtotpay{
		

			quiet summ ln_`var' if sample==1 & ag2==1, d
			scalar min_1 = r(p1)
			scalar max_1 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==2, d
			scalar min_2 = r(p1)
			scalar max_2 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==3, d
			scalar min_3 = r(p1)
			scalar max_3 = r(p99)
		
			quiet summ ln_`var' if sample==1 & ag2==4, d
			scalar min_4 = r(p1)
			scalar max_4 = r(p99)
			
			twoway (lpoly chooseB ln_`var' if ag2==1 & sample==1 & ln_`var'>=min_1 & ln_`var'<max_1 & sample==1 & ln_`var'>3.9, lcolor(maroon) lpattern(dash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==2 & sample==1 & ln_`var'>=min_2 & ln_`var'<max_2 & sample==1 & ln_`var'>3.9, lcolor(dkorange) lpattern(..-) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==3 & sample==1 & ln_`var'>=min_3 & ln_`var'<max_3 & sample==1 & ln_`var'>3.9, lpattern(shortdash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==4 & sample==1 & ln_`var'>=min_4 & ln_`var'<max_4 & sample==1 & ln_`var'>3.9, lcolor(gs10) lpattern(solid) lwidth(medthick)), /*
		 	 */ xtitle("realized healthcare costs, time {it:t}") xlabel(4.094 "$60" 5.52 "$250" 6.9 "$1000"  8.29 "$4k" 9.68 "$16k" 11.067 "$64k" , grid )  /*
		 	 */ ytitle("Chose Plan {it:H}") ylabel(.1(.1).7) /*
		 	 */ legend(off) /*
		 	 */ aspectratio(1) /*
		 	 */ graphregion(color(white)) /*
		 	 */ subtitle("zeros transformed")  saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'realized1.gph", replace)

 			graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'realized1.pdf", replace
}


foreach var in totpay{
		

			quiet summ ln_`var' if sample==1 & ag2==1, d
			scalar min_1 = r(p1)
			scalar max_1 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==2, d
			scalar min_2 = r(p1)
			scalar max_2 = r(p99)
			
			quiet summ ln_`var' if sample==1 & ag2==3, d
			scalar min_3 = r(p1)
			scalar max_3 = r(p99)
		
			quiet summ ln_`var' if sample==1 & ag2==4, d
			scalar min_4 = r(p1)
			scalar max_4 = r(p99)
			
			twoway (lpoly chooseB ln_`var' if ag2==1 & sample==1 & ln_`var'>=min_1 & ln_`var'<max_1 & sample==1 & ln_`var'>3.9, lcolor(maroon) lpattern(dash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==2 & sample==1 & ln_`var'>=min_2 & ln_`var'<max_2 & sample==1 & ln_`var'>3.9, lcolor(dkorange) lpattern(..-) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==3 & sample==1 & ln_`var'>=min_3 & ln_`var'<max_3 & sample==1 & ln_`var'>3.9, lpattern(shortdash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==4 & sample==1 & ln_`var'>=min_4 & ln_`var'<max_4 & sample==1 & ln_`var'>3.9, lcolor(gs10) lpattern(solid) lwidth(medthick)), /*
		 	 */ xtitle("realized healthcare costs, time {it:t}") xlabel(4.094 "$60" 5.52 "$250" 6.9 "$1000"  8.29 "$4k" 9.68 "$16k" 11.067 "$64k" , grid )  /*
		 	 */ ytitle("Chose Plan {it:H}") ylabel(.1(.1).7) /*
		 	 */ legend(off) /*
		 	 */ aspectratio(1) /*
		 	 */ graphregion(color(white)) /*
		 	 */ subtitle("zeros dropped")  saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'realized2.gph", replace)
		 	 
 			graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'realized2.pdf", replace
}

//Generate additional legend
foreach var in totpay{
		
			twoway (lpoly chooseB ln_`var' if ag2==1 & sample==1 & ln_`var'>=min_1 & ln_`var'<max_1 & sample==1 & ln_`var'>3.9, lcolor(maroon) lpattern(dash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==2 & sample==1 & ln_`var'>=min_2 & ln_`var'<max_2 & sample==1 & ln_`var'>3.9, lcolor(dkorange) lpattern(..-) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==3 & sample==1 & ln_`var'>=min_3 & ln_`var'<max_3 & sample==1 & ln_`var'>3.9, lpattern(shortdash) lwidth(medthick)) /*
		 	 */ (lpoly chooseB ln_`var' if ag2==4 & sample==1 & ln_`var'>=min_4 & ln_`var'<max_4 & sample==1 & ln_`var'>3.9, lcolor(gs10) lpattern(solid) lwidth(medthick)), /*
		 	 */ xtitle("realized healthcare costs, {it:t}") xlabel(3.91 "$50" 5.52 "$250" 6.9 "$1000"  8.29 "$4k" 9.68 "$16k" , grid )  /*
		 	 */ ytitle("Pr(choose H)") ylabel(.1(.1).7) /*
		 	 */ graphregion(color(white)) /*
		 	 */ aspectratio(1) /*
		 	 */ legend(label(1 "18-29") label(2 "30-39") label(3 "40-49") label(4 "50-59") row(1)) 
		 	 
 			graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'legend.pdf", replace
}
		 	  

