


clear
clear mata
clear matrix
set mem 6g
set more off

global SOURCE "/disk/aging/medstat/data/sas"
global BULK "/disk/agebulk2/medstat.work/gerusom"
global WORK "/disk/agedisk3/medstat.work/gerusom"
global SCRATCH "/disk/agescratch4/gerusom"

global DISTR "/disk/agedisk3/medstat.work/gerusom/Results/Distr"

sysdir set PERSONAL "/disk/homes2b/nber/gerusom/ado/plus/personal"

use "$WORK/Data/Main_wRandoms.dta", clear



/*----------------------------------------
Set Coefficients
----------------------------------------*/

cap drop coeff_*
gen coeff_eps = 1350
gen coeff_gamma = .0006957
gen coeff_ag2_4 = 508
gen coeff_ag2_3 = 322
gen coeff_ag2_2 = 261
gen coeff_female = 179
gen coeff_planB = -832

gen coeff_alt_eps = coeff_eps //*3240/520

/*----------------------------------------
Calculate Welfare And Choices
----------------------------------------*/


*----------------------------------------------------------
*----------------------------------------------------------
*----First calculate the portion of the utility function that can be separated out from DeltaP and epsilon
*----Call this Wj = INT[exp(gamma(OOP - Planj - femj - SUM(agej)))dFj(OOP)]. All items in money term drop out for plan L, except OOP
*----Note no negative sign before exp()
*----Choice will be to choose H iff: 
*----exp(gamma(deltaP - eps))*-WH > -WL
*----exp(gamma(deltaP - eps))*WH < WL
*----Which is the same as deltaP + eps < ln(WL/WH)/gamma


*Distribution of medical cost risk
cap drop use_*
cap drop oop_*
local Q = 200

forvalues i=1(1)`Q'{
	*want Pr always to lie btwn 0 and 1, (thus cant have it equal Q/Q or 0/Q)
	local Pr = `i'/`Q' - 1/(2*`Q')
	quiet gen use_`i' = exp(lnN_u + lnN_sig*invnormal(`Pr'))
}

*Distribution of OOP risk, based on medical risk (use_i)
forvalues i=1(1)`Q'{
	quiet gen double oop_`i' = use_`i' if use_`i'<ided_
	quiet replace oop_`i' = ided_ + (use_`i'-ided_)*coins_ if use_`i'>ided_ & use_`i'~=.
	quiet replace oop_`i' = ioop_ if oop_`i'>ioop_ & use_`i'~=.
	quiet replace oop_`i' = 0 if oop_`i'<0
}

*simulation draws for numerically integrating to expected utility
cap drop sum
gen double sum = 0
forvalues i=1(1)`Q'{
	quiet replace sum = sum + exp(coeff_gamma*(oop_`i' - agegrp2*coeff_ag2_2 - agegrp3*coeff_ag2_3 - agegrp4*coeff_ag2_4 - female*coeff_fem - planB*coeff_planB))
}


*----Expected utility needs to also average in the utility of zero OOP loss, which hasn't been accounted for yet.
cap drop W_j
cap drop W_distr
quiet gen double W_distr = sum/(`Q') //welfare of the positive spending outcome
cap drop W_zero //welfare of the no-spending outcome

*After taking expectation of utility over non-zero portion of utilization distribution, avg with zero mass
*E(U(use>0))*Pr(use>0) + E(U(0))*Pr(use=0)
gen W_zero = exp(coeff_gamma*(0 - agegrp2*coeff_ag2_2 - agegrp3*coeff_ag2_3 - agegrp4*coeff_ag2_4 - female*coeff_fem - planB*coeff_planB))
gen W_j = W_distr*(1-Pr_zero) + W_zero*Pr_zero if sample==1

cap drop W_zero
cap drop W_distr
cap drop sum


*----------------------------------------------------------
*----------------------------------------------------------
*----Next calculate the fraction of epsilons that generate a choice of H 
*----This will be conditional on some deltaP
*----choose H iff: deltaP - eps < ln(WL/WH)/gamma

*----Get WH and WL on same obs (line)

cap drop temp*
cap drop WH
cap drop WL
cap drop WN
egen temp = max(W_j) if plan=="B", by(enrolid year)
egen WH = max(temp), by(enrolid year)
cap drop temp
egen temp = max(W_j) if plan=="A", by(enrolid year)
egen WL = max(temp), by(enrolid year)
cap drop temp
egen temp = max(W_j) if plan=="N", by(enrolid year)
egen WN = max(temp), by(enrolid year)

*----For fixed deltaP, what is Pr(H|deltaP) for person i, given the distribution of epsilon?
*----choose H iff: deltaP - eps < ln(WL/WH)/gamma

/*
cap drop temp1
cap drop temp2
gen temp1 = (ln(WL) - ln(WH))/coeff_gamma  //new
gen temp2 = (ln(WL/WH))/coeff_gamma //old 
*/

gen utilityH = (ln(WL) - ln(WH))/coeff_gamma
gen utilityAltH = (ln(WN) - ln(WH))/coeff_gamma

/*----------------------------------------
Assign Idiosynchratic Tastes and Calculate Valuations
----------------------------------------*/



/*
Difference in valuation vH - vL is diff in CE plus taste shock
This gives diff in value in dollars:
CE = ln(Wj)/-gamma
So Delta CE = ln(WH)/-gamma - ln(WL)/-gamma + epsilon
            = -1/gamma(ln(WH/WL)) + epsilon = 1/gamma(ln(WL/WH)) + epsilon
         
Alternatively, can plot difference in Expected utility, but units/scale are meaningless:
= -1/gamma*[exp(-gamma*epsilon)*WH - WL]

*/

cap drop shock* CEvH* vH*

quiet gen shock = coeff_eps*invnormal(uniform)
quiet gen CEvH = (ln(WL) - ln(WH))/coeff_gamma + shock
label var CEvH "difference in CE valuation of H over L, including taste shock"

quiet gen CEnoshock = (ln(WL) - ln(WH))/coeff_gamma
label var CEnoshock "difference in CE valuation of H over L, not including taste shock"


quiet gen vH = -(exp(-coeff_gamma*shock)*WH - WL)/coeff_gamma
label var vH "difference in E[utility] of H over L, including taste shock"

quiet gen shock_small = coeff_eps_small*invnormal(uniform)
quiet gen CEvH_small = (ln(WL) - ln(WH))/coeff_gamma + shock_small
label var CEvH_small "difference in CE valuation of H over L, including taste shock"

quiet gen vH_small = -(exp(-coeff_gamma*shock_small)*WH - WL)/coeff_gamma
label var vH_small "difference in E[utility] of H over L, including taste shock"

/*----------------------------------------
FIGURE 7 Plots
----------------------------------------*/


//Keep just one observation per person year
keep if planB==1
keep if sample==1


foreach var in CEvH {
	foreach age in 1 2 3 4{
			quiet summ `var' if ag2==`age', d
			scalar min_`age' = r(p5)
			scalar max_`age' = r(p95)
	}
}		
cap drop xavg*
*gen xavg = .
egen xavg = mean(CEnoshock), by(ag2 Ecost1diff1)
foreach var in CEnoshock {
	foreach age in 1 2 3 4{
			
	}
}	


cap drop x45
cap drop y45
gen x45 = 0 in 1
replace x45 = 1000 in 2
gen y45 = 0 in 1
replace y45 = 1000 in 2

twoway 		(scatter CEvH Ecost1diff1 if ag2==4 & CEvH>=-3000 & CEvH<5500, mlwidth(vvthin) mcolor(gs10) msymbol(oh) msize(med)  ) ///
		(scatter CEvH Ecost1diff1 if ag2==1 & CEvH>=-3500 & CEvH<4500, msymbol(o) msize(small) ) ///	
		(scatter xavg Ecost1diff1 if ag2==4 & CEvH>=-3000 & CEvH<5500, msymbol(+) msize(med) mcolor(gs5) ) ///	
		(scatter xavg Ecost1diff1 if ag2==1 & CEvH>=-3500 & CEvH<4500, msymbol(+) msize(med) mcolor(olive) )  ///		
		(scatter y45 x45 in 1/2, connect(direct) msymbol(none) lwidth(medthick) lcolor(black) lpattern(dot)), ///
		graphregion(color(white)) bgcolor(white) ///
		xtitle("expected cost difference, {it:c{sub:iH}-c{sub:iL}}") ///
		xlabel(0 "$0" 250 "$250" 500 "$500" 750 "$750" 1000 "$1000", nogrid) ///
		ylabel(-2500 "-$2500" 0 "$0" 2500 "$2500" 5000 "$5000" ,nogrid)  ///
		ytitle("valuation difference, {it:v{sub:iH}-v{sub:iL}}")  aspectratio(1) ///
		legend(label(2 "18-29") label(1 "50-59") order(2 1) row(2) ring(0) position(5) bmargin(medium)) ///
 		name(v2, replace) saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'simHetero_2.gph", replace)
		graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'simHetero_2.pdf", replace
		
twoway 		(scatter CEvH Ecost1diff1 if ag2==4 & CEvH>=-3000 & CEvH<5500, mlwidth(vvthin) mcolor(gs10) msymbol(oh) msize(med)  ) ///
		(scatter CEvH Ecost1diff1 if ag2==1 & CEvH>=-3500 & CEvH<4500, msymbol(o) msize(small) ) ///	
		(scatter y45 x45 in 1/2, connect(direct) msymbol(none) lwidth(medthick) lcolor(black) lpattern(dot)), ///
		graphregion(color(white)) bgcolor(white) ///
		xtitle("expected cost difference, {it:c{sub:iH}-c{sub:iL}}") ///
		xlabel(0 "$0" 250 "$250" 500 "$500" 750 "$750" 1000 "$1000", nogrid) ///
		ylabel(-2500 "-$2500" 0 "$0" 2500 "$2500" 5000 "$5000" ,nogrid)  ///
		ytitle("valuation difference, {it:v{sub:iH}-v{sub:iL}}")  aspectratio(1) ///
		legend(label(2 "18-29") label(1 "50-59") order(2 1) row(2) ring(0) position(5) bmargin(medium)) ///
 		name(v2b, replace) saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'simHetero_2.gph", replace)
		graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'simHetero_2b.pdf", replace
		
			
twoway 		(scatter CEvH_small Ecost1diff1 if ag2==4 & CEvH_small>=-1500 & CEvH_small<2500, mlwidth(vvthin) mcolor(gs10) msymbol(oh) msize(med)  ) ///
		(scatter CEvH_small Ecost1diff1 if ag2==1 & CEvH_small>=-1900 & CEvH_small<1500, msymbol(o) msize(small) ) ///		
		(scatter y45 x45 in 1/2, connect(direct) msymbol(none) lwidth(medthick) lcolor(black) lpattern(dot)), ///
		graphregion(color(white)) bgcolor(white) ///
		xtitle("expected cost difference, {it:c{sub:iH}-c{sub:iL}}") ///
		xlabel(0 "$0" 250 "$250" 500 "$500" 750 "$750" 1000 "$1000", nogrid) ///
		ylabel(-2000 "-$2000" -1000 "-$1000" 0 "$0" 1000 "$1000" 2000 "$2000" ,nogrid)  ///
		ytitle("valuation difference, {it:v{sub:iH}-v{sub:iL}}")  aspectratio(1) ///
		legend(label(2 "18-29") label(1 "50-59") order(2 1) row(2) ring(0) position(5) bmargin(medium)) ///
 		name(v3, replace) saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'simHetero3.gph", replace)
		graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'simHetero_3.pdf", replace

