
/*
nohup nice stata do Structural_JUN30-2011.do &
nohup nice  stata -b do Simulation-2016-5-16 &
kill -3 PID
kill -6 PID
*/
*----------------------------------------------------
*----------------------------------------------------
* Load data
*----------------------------------------------------
*----------------------------------------------------


clear
clear mata
clear matrix
set mem 6g
set more off

global SOURCE "/disk/aging/medstat/data/sas"
global BULK "/disk/agebulk2/medstat.work/gerusom"
global WORK "/disk/agedisk3/medstat.work/gerusom"
global SCRATCH "/disk/agescratch4/gerusom"

global DISTR "/disk/agedisk3/medstat.work/gerusom/Results/Distr"

sysdir set PERSONAL "/disk/homes2b/nber/gerusom/ado/plus/personal"



use "$WORK/Data/Cleaned_merged_MAY072011.dta", clear


local year = 2006
keep if year==`year'
keep if count_fam==1



*----------------------------------------------------
*----------------------------------------------------
* Find parameters of individual-specific OOP distribution
*----------------------------------------------------
*----------------------------------------------------
*----------------------------------------------------
*----------------------------------------------------
*----Group enrollees into cells by age/sex?/predicted use
*----------------------------------------------------
*----------------------------------------------------

*Create residual between expected and realized
gen pred_err = totdoc - preddoc

cap drop sample
gen sample = 1 if preddoc~=.

cap drop cell_grp
cap drop cellgrp_*
gen cell_grp = .
label var cell_grp "group id, with value = 1000 + 100*`age'+ 1*bottom decile of cell"

forvalues age=1(1)4{
	
	*----find modal value of preddoc that corresponds essentially to the lower bound of the prediction
	*----necessary because this value may be the value of pctile(1)-pctile(30) and we need to know to create bins
	
	_pctile preddoc if ag2==`age' & sample==1, percentiles(10)
	cap drop temp*
	di r(r10)
	gen temp_p10 = r(r1)
	
	count if ag2==`age' & sample==1 & preddoc<(temp_p10 + .01)
	local temp_num = r(N)
	count if ag2==`age' & sample==1
	local temp_den = r(N)
	local temp_fract= `temp_num'/`temp_den'
	
	*count if ag2==`age' & sample==1 & nodoc_2005==1
	*count if ag2==`age' & sample==1 & preddoc<512

	*----Find Deciles
	*round fraction to next highest pctile - this will be the first pctile of interest.
	*if fraction is more than halfway to next pctile, lump the remaining fraction of pctile into the next cell
	
	local temp_ceil = ceil(10*`temp_fract')
	di `temp_fract'
	di `temp_ceil'

	local temp_collapse_up = (`temp_ceil' - 10*`temp_fract' < .5) //less than half the pctile is higher than the p10 value
	di `temp_collapse_up'
	
	local first_cellmax_pctile = `temp_ceil' + `temp_collapse_up'
	local first_cellmax_pctileminus1 = `first_cellmax_pctile' - 1
	
	
	cap drop pct
	pctile pct = preddoc if ag2==`age' & sample==1, nq(10)
	list pct in 1/9
	_pctile  preddoc if ag2==`age' & sample==1, percentiles(10(10)90)
	return list
	
	*----Assign people to age x decile groups, lumping bottom groups together if the first few deciles are identical
	
	*handle the (0-x] cell, the (x,firstcellmax] and (90,100] groups separately
	local pctile9 = pct in 9
	local pctilex = pct in `first_cellmax_pctile'

	
	replace cell_grp = 1000 + 100*`age'+ 1*0  				if ag2==`age' & (preddoc<(temp_p10 + .01)) & sample==1
	replace cell_grp = 1000 + 100*`age'+ 1*(`first_cellmax_pctile'-1)  	if ag2==`age' & (preddoc>=(temp_p10 + .01)) & preddoc<`pctilex' & sample==1
	replace cell_grp = 1000 + 100*`age'+ 1*9  				if ag2==`age' & preddoc>=`pctile9' & sample==1
	
	gen cellgrp_`age'_0 = 0
	gen cellgrp_`age'_`first_cellmax_pctileminus1' = 0
	gen cellgrp_`age'_9 = 0

	replace cellgrp_`age'_0 = 1 				if ag2==`age' & (preddoc<(temp_p10 + .01)) & sample==1
	replace cellgrp_`age'_`first_cellmax_pctileminus1'= 1  	if ag2==`age' & (preddoc>=(temp_p10 + .01)) & preddoc<`pctilex' & sample==1
	replace cellgrp_`age'_9  = 1				if ag2==`age' & preddoc>=`pctile9' & sample==1

	
	forvalues pctile=`first_cellmax_pctile'(1)8{
	
		local cellmin = pct in `pctile'
		local next = `pctile' + 1
		local cellmax = pct in `next'
		
		replace cell_grp = 1000 + 100*`age'+ 1*`pctile' if ag2==`age' & (preddoc>=`cellmin') & (preddoc<`cellmax') & sample==1
		
		gen cellgrp_`age'_`pctile' = 0
		replace cellgrp_`age'_`pctile' = 1 if ag2==`age' & (preddoc>=`cellmin') & (preddoc<`cellmax') & sample==1
	}
	

}

*----Make sure that deciles look correct, including the larger bottom quantile
ta cell_grp if ag2==1 & sample==1, mis
ta cell_grp if ag2==2 & sample==1, mis
ta cell_grp if ag2==3 & sample==1, mis
ta cell_grp if ag2==4 & sample==1, mis

*----Make sure everyone with a predicted use is in one and only one group
egen check_multicell_membership = rowtotal(cellgrp_1_0-cellgrp_1_8 cellgrp_2_0-cellgrp_2_8 cellgrp_3_0-cellgrp_3_8 cellgrp_4_0-cellgrp_4_8)
ta check_multicell_membership, mis
count if check_multicell_membership==0 & age<60 & age>=18 & preddoc~=.


*----------------------------------------------------
*----------------------------------------------------
*----Parameterize distribution within cell
*----------------------------------------------------
*----------------------------------------------------

*----FIND THE MASS AT ZERO

cap drop Pr_zero
gen Pr_zero = .

cap drop sample
gen sample=1 if preddoc~=.

forvalues age=1(1)4{
	forvalues pctile=0(1)9{
		local group = 1000+100*`age' + 1*`pctile' 
		quiet count if cell_grp==`group'
		if r(N)>0{
				
			count if cell_grp==`group' & sample==1 & totdoc==0
			local temp_num = r(N)
			count if cell_grp==`group' & sample==1 & totdoc>=0 & totdoc~=.
			local temp_den = r(N)
			local temp_fract= `temp_num'/`temp_den'	
			
			replace Pr_zero = `temp_fract' if cell_grp==`group'
		
			di "group: " `group'
			di "fraction with zero realized use: " `temp_fract'
						 
		}
	}
}


*----LOGNORMAL ML ESTIMATION

*----Estimate distribution of realized cost within cell by ML
*----Find parameters of lnnormal

cap drop lntotdoc
gen lntotdoc = ln(totdoc)

cap drop sample
gen sample = 1 if totdoc>0 & preddoc~=.

cap drop lnN_*
gen lnN_u = .
gen lnN_sig2 = .
gen lnN_mean = .

label var lnN_u "lnNorm location parameter within decile-age cell"
label var lnN_sig2 "lnNorm variance parameter within decile-age cell"
label var lnN_mean "lnNorm implied mean within decile-age cell; zero mass not included"

forvalues age=1(1)4{
	forvalues pctile=0(1)9{
		local group = 1000+100*`age' + 1*`pctile' 
		quiet count if cell_grp==`group'
		if r(N)>0{

			quiet summ lntotdoc if cell_grp==`group' & sample==1
			
			replace lnN_u = r(mean) if cell_grp==`group'
			replace lnN_sig2 = r(Var) if cell_grp==`group'
			replace lnN_mean = exp(lnN_u + lnN_sig2/2) if cell_grp==`group'
		
			di "group: " `group'
			di "from lnN: " exp(r(mean) + r(Var)/2)
			quiet summ totdoc if cell_grp==`group' & sample==1
			di "actual mean: " r(mean)
			

		}
	}
}


*----------------------------------------------------
*----------------------------------------------------
* Create new vars for reshape for structural estimation and sim
* B is high coverage plan. N is no coverage.
*----------------------------------------------------
*----------------------------------------------------


gen ided_A =.
gen ided_B =.
gen ided_N =.
replace ided_A = 500 if year>=2005 & year<=2007
replace ided_B = 300 if year>=2005 & year<=2007
replace ided_N = 10000000 if year>=2005 & year<=2007
 
gen coins_A =.
gen coins_B =.
gen coins_N =.
replace coins_A = .20 if year>=2005 & year<=2007
replace coins_B = .10 if year>=2005 & year<=2007 
replace coins_N = 1.0 if year>=2005 & year<=2007 

gen ioop_A =4250
gen ioop_B =2300
gen ioop_N =10000000


*----------------------------------------------------
*----------------------------------------------------
*----RESHAPE
*----------------------------------------------------
*----------------------------------------------------


reshape long OOP_ ided_ coins_ ioop_, i(patient_id) j(plan) string

cap drop sample
gen sample=1 if preddoc~=. & lnN_u~=. & emprel==1 & count_fam==1 
count if lnN_u~=. & preddoc==.

keep if sample==1

*----------------------------------------------------
*----------------------------------------------------
*----Create some indicators and placeholder variables for estimator - some of the values are irrelevant
*----------------------------------------------------
*----------------------------------------------------

gen epsilon_B = 0
replace epsilon_B = uniform() if plan=="B"
*label var epsilon_B "placeholder only-contains no real data"

gen gamma = uniform()
*label var gamma "placeholder only-contains no real data"

*----Create some indicator variables for structural estimator - dummies interacted with plan

gen agegrp1 = 0
replace agegrp1 = 1 if ag2==1 & plan=="B"
label var agegrp1 "age 18-29"

gen agegrp2 = 0
replace agegrp2 = 1 if ag2==2 & plan=="B"
label var agegrp2 "age 30-39"

gen agegrp3 = 0
replace agegrp3 = 1 if ag2==3 & plan=="B"
label var agegrp3 "age 40-49"

gen agegrp4 = 0
replace agegrp4 = 1 if ag2==4 & plan=="B"
label var agegrp4 "age 50-59"

gen planB = 0
replace planB = 1 if plan=="B"

gen female = 0
replace female = 1 if fem==1 & plan=="B"
label var female "interaction fem x B"

gen lnpred = ln(preddoc)

gen ln_se = 1

*----------------------------------------------------
*----Find Avg Cost TO EMPLOYER in group

*1. find utilization, with drugs separate
*2. convert it to the employer payment using OOP rules, and using actual employer payments for drugs, since these dont differ by plans
*3. find avg cost to employer conditional on the plan chosen, (real or cf)


*find non-drug and drug utilization
gen non_drug = out_totpay + in_totpay
gen employer_drug = pharm_totpay - pharm_deduct - pharm_copay - pharm_coins
compare totdoc non_drug //same

cap drop employer_cost
gen employer_cost = .
label var employer_cost "total cost to employer of enrolling patient"

*----find predicted cost difference between H and L associated with each enrollee
cap drop pred_employer_cost
gen pred_employer_cost = .
label var pred_employer_cost "predicted cost to employer of enrolling patient (no drug)"


/**********************************************************************************

Sample and new employer and consumer cost vars

**********************************************************************************/



//Define person and plan cost differentials

//Person Expected OOP 2 (expectation of OOP costs)
//Put expected cost through the coinsurance/deductible formula and get enrollee OOP cost
cap drop temp*
cap drop EOOP2*
gen EOOP2 = preddoc if preddoc<ided_ & sample==1
replace EOOP2 = (preddoc - ided_)*coins_ + ided_ if preddoc>=ided_ & sample==1
replace EOOP2 = ioop_ if EOOP2>ioop_ & EOOP2~=. & sample==1
label var EOOP2 "OOP of expected non-drug costs"
egen temp1 = max(EOOP2) if plan=="B", by(enrolid year)
egen EOOP2H = max(temp1), by(enrolid year)
label var EOOP2H "H OOP of expected costs; ignore concavity of cost sharing"
egen temp2 = max(EOOP2) if plan=="A", by(enrolid year)
egen EOOP2L = max(temp2), by(enrolid year)
label var EOOP2L "L OOP of expected costs; ignore concavity of cost sharing"
egen temp3 = max(EOOP2) if plan=="N", by(enrolid year)
egen EOOP2N = max(temp3), by(enrolid year)
label var EOOP2N "N OOP of expected costs; ignore concavity of cost sharing"


//Plan Expected spending
//Put expected cost through the coinsurance/deductible formula and get employer expected cost; ignores concavity of cost sharing
cap drop temp*
cap drop Ecost2*
gen Ecost2 = pred_employer_cost
egen temp1 = max(Ecost2) if plan=="B", by(enrolid year)
egen Ecost2H = max(temp1), by(enrolid year)
label var Ecost2H "H Employer expected costs; ignore concavity of cost sharing"
egen temp2 = max(Ecost2) if plan=="A", by(enrolid year)
egen Ecost2L = max(temp2), by(enrolid year)
label var Ecost2L "L Employer expected costs; ignore concavity of cost sharing"
egen temp3 = max(Ecost2) if plan=="N", by(enrolid year)
egen Ecost2N = max(temp3), by(enrolid year)
label var Ecost2N "N Employer expected costs; ignore concavity of cost sharing"

//Check that the total predicted spending sums correctly
cap drop checksum_preddoc
gen checksum_preddoc = Ecost2 + EOOP2
compare checksum_preddoc preddoc // the employer and employee portion of predicted spending should sum to the total prediction

//Do expected OOP spending accounting for concavity: Take average of OOP over the distribution of outcomes
//Distribution of medical cost risk
cap drop use_*
cap drop oop_*
cap drop emp_*
cap drop sum_oop
cap drop sum_employer
cap drop sum_use
gen double sum_oop = 0
gen double sum_employer = 0
gen double sum_use = 0
local Q = 200
forvalues i=1(1)`Q'{
	//want Pr always to lie btwn 0 and 1, otherwise invnormal is infinite, (thus cant have it equal Q/Q or 0/Q)
	local Pr = `i'/`Q' - 1/(2*`Q')
	//
	quiet gen use_`i' = exp(lnN_u + lnN_sig*invnormal(`Pr'))
	//enrollee OOP costs	
	quiet gen double oop_`i' = use_`i' if use_`i'<ided_
	quiet replace oop_`i' = ided_ + (use_`i'-ided_)*coins_ if use_`i'>ided_ & use_`i'~=.
	quiet replace oop_`i' = ioop_ if oop_`i'>ioop_ & use_`i'~=.
	quiet replace oop_`i' = 0 if oop_`i'<0
	//plan costs
	quiet gen double emp_`i' = use_`i' - oop_`i'
	//running sums
	quiet replace sum_oop = sum_oop + oop_`i'
	quiet replace sum_employer = sum_employer + emp_`i'
	quiet replace sum_use = sum_use + use_`i'
	
}

//Person, Plan Expected Costs 1 (Correctly calculates OOP of expected OOP costs)
//Part 1: calculate conditional on a draw from the lnNormal part of the distribution
cap drop temp*
cap drop EOOP1*
cap drop Ecost1*
cap drop meanOOP
cap drop varOOP
cap drop meanUse
quiet gen double EOOP1 = sum_oop/(`Q')
quiet gen double Ecost1 = sum_emp/(`Q')
quiet gen double meanUse = sum_use/(`Q')

//a quick and dirty check that simulating the mean gets the mean basically correct for the lognormal part
gen temp_mean = exp(lnN_u + .5*lnN_sig*lnN_sig) //formula for lnNormal mean
compare temp_mean meanUse
summ temp_mean meanUse
//check the full prediction
replace temp_mean = temp_mean*(1-Pr_zero)
compare preddoc temp_mean

//Part 2: calculate conditional on the zero point mass
replace EOOP1 = EOOP1*(1-Pr_zero)
replace Ecost1 = Ecost1*(1-Pr_zero)

ta plan, summ(Ecost1)


cap drop temp*
cap drop Ecost1H 
cap drop Ecost1L
cap drop Ecost1N
egen temp1 = max(Ecost1) if plan=="B", by(enrolid year)
egen Ecost1H = max(temp1), by(enrolid year)
label var Ecost1H "H Employer expected costs"
egen temp2 = max(Ecost1) if plan=="A", by(enrolid year)
egen Ecost1L = max(temp2), by(enrolid year)
label var Ecost1L "L Employer expected costs"
egen temp3 = max(Ecost1) if plan=="N", by(enrolid year)
egen Ecost1N = max(temp3), by(enrolid year)
label var Ecost1N "N Employer expected costs"
cap drop temp*
egen temp1 = max(EOOP1) if plan=="B", by(enrolid year)
egen EOOP1H = max(temp1), by(enrolid year)
label var EOOP1H "H OOP of expected costs"
egen temp2 = max(EOOP1) if plan=="A", by(enrolid year)
egen EOOP1L = max(temp2), by(enrolid year)
label var EOOP1L "L OOP of expected costs"
egen temp3 = max(EOOP1) if plan=="N", by(enrolid year)
egen EOOP1N = max(temp3), by(enrolid year)
label var EOOP1N "N OOP of expected costs"


foreach var in EOOP1 EOOP2 Ecost1 Ecost2{
	gen `var'diff1 = `var'H - `var'L
	label var `var'diff1 "`var'H - `var'L"
	
	gen `var'diff2 = `var'H - `var'N
	label var `var'diff2 "`var'H - `var'N"
}

/*----------------------------------------
Save
----------------------------------------*/

set seed 6187 //random.org 1 to 10,000 
gen uniform = uniform()

/*
*save "$WORK/Data/Main_wRandoms.dta", replace


clear
clear mata
clear matrix
set mem 6g
set more off

global SOURCE "/disk/aging/medstat/data/sas"
global BULK "/disk/agebulk2/medstat.work/gerusom"
global WORK "/disk/agedisk3/medstat.work/gerusom"
global SCRATCH "/disk/agescratch4/gerusom"

global DISTR "/disk/agedisk3/medstat.work/gerusom/Results/Distr"

*sysdir set PERSONAL "/disk/homes2b/nber/gerusom/ado/plus/personal"
sysdir set PERSONAL "/disk/homedirs/gerusom/ado/plus/personal"

use "$WORK/Data/Main_wRandoms.dta", clear

*/


*----------------------------------------------------
*----Simulate CF choices

*1. assign each person multiple draws from epsilon (that are deterministic because they are at fixed intervals over the CDF)
*2. calculate expected utility by averaging over F(OOP)  
*3. gen simulated choice probabilities

*----Details on the evolution of prices:
*1. calculate initial community prices for t0 based on actual community choices (this is like t-1 average costs). this is just equal to the communty prices assumed in the estimation
*2. Simulate plan choices under community prices for t0
*3. Calculate categorical prices for t1 based on the age-specific average costs of plan choices made under community prices in t0
*4. Calculate new categorical prices for t2 based on average costs of plan enrollment in t1...


/*----------------------------------------
********ENTER COEFFICIENTS HERE************
----------------------------------------*/


* estimates based on price = 695 = 20% of AC diff , implies H dummy = -832
cap drop coeff_*
gen coeff_eps = 1350
gen coeff_gamma = .0006957
gen coeff_ag2_4 = 508
gen coeff_ag2_3 = 322
gen coeff_ag2_2 = 261
gen coeff_female = 179
gen coeff_planB = -832

gen coeff_alt_eps = coeff_eps //coeff_eps*3240/520


/*----------------------------------------
********ENTER COEFFICIENTS HERE************
----------------------------------------*/

*----------------------------------------------------------
*----------------------------------------------------------
*----First calculate the portion of the utility function that can be separated out from DeltaP and epsilon
*----Call this Wj = INT[exp(gamma(OOP - Planj - femj - SUM(agej)))dFj(OOP)]. All items in money term drop out for plan L, except OOP
*----Note no negative sign before exp()
*----Choice will be to choose H iff: 
*----exp(gamma(deltaP - eps))*-WH > -WL
*----exp(gamma(deltaP - eps))*WH < WL
*----Which is the same as deltaP + eps < ln(WL/WH)/gamma


*Distribution of medical cost risk
cap drop use_*
cap drop oop_*
local Q = 200

forvalues i=1(1)`Q'{
	*want Pr always to lie btwn 0 and 1, (thus cant have it equal Q/Q or 0/Q)
	local Pr = `i'/`Q' - 1/(2*`Q')
	quiet gen use_`i' = exp(lnN_u + lnN_sig*invnormal(`Pr'))
}

*Distribution of OOP risk, based on medical risk (use_i)
forvalues i=1(1)`Q'{
	quiet gen double oop_`i' = use_`i' if use_`i'<ided_
	quiet replace oop_`i' = ided_ + (use_`i'-ided_)*coins_ if use_`i'>ided_ & use_`i'~=.
	quiet replace oop_`i' = ioop_ if oop_`i'>ioop_ & use_`i'~=.
	quiet replace oop_`i' = 0 if oop_`i'<0
}

*simulation draws for numerically integrating to expected utility
cap drop sum
gen double sum = 0
forvalues i=1(1)`Q'{
	quiet replace sum = sum + exp(coeff_gamma*(oop_`i' - agegrp2*coeff_ag2_2 - agegrp3*coeff_ag2_3 - agegrp4*coeff_ag2_4 - female*coeff_fem - planB*coeff_planB))
}


*----Expected utility needs to also average in the utility of zero OOP loss, which hasn't been accounted for yet.
cap drop W_j
cap drop W_distr
quiet gen double W_distr = sum/(`Q') //welfare of the positive spending outcome
cap drop W_zero //welfare of the no-spending outcome

*After taking expectation of utility over non-zero portion of utilization distribution, avg with zero mass
*E(U(use>0))*Pr(use>0) + E(U(0))*Pr(use=0)
gen W_zero = exp(coeff_gamma*(0 - agegrp2*coeff_ag2_2 - agegrp3*coeff_ag2_3 - agegrp4*coeff_ag2_4 - female*coeff_fem - planB*coeff_planB))
gen W_j = W_distr*(1-Pr_zero) + W_zero*Pr_zero if sample==1

cap drop W_zero
cap drop W_distr
cap drop sum


*----------------------------------------------------------
*----------------------------------------------------------
*----Next calculate the fraction of epsilons that generate a choice of H 
*----This will be conditional on some deltaP
*----choose H iff: deltaP - eps < ln(WL/WH)/gamma

*----Get WH and WL on same obs (line)

cap drop temp*
cap drop WH
cap drop WL
cap drop WN
egen temp = max(W_j) if plan=="B", by(enrolid year)
egen WH = max(temp), by(enrolid year)
cap drop temp
egen temp = max(W_j) if plan=="A", by(enrolid year)
egen WL = max(temp), by(enrolid year)
cap drop temp
egen temp = max(W_j) if plan=="N", by(enrolid year)
egen WN = max(temp), by(enrolid year)

gen utilityH = (ln(WL) - ln(WH))/coeff_gamma
gen utilityAltH = (ln(WN) - ln(WH))/coeff_gamma


/**********************************************************************************
***********************************************************************************

Simulated plan choice under assumed price

***********************************************************************************
**********************************************************************************/

global MIN = 690
global MAX = 700
global STEP = 5


//Ecost1diff1 = the correct measure of MC comparing H to L
//Ecost1diff2 =the correct measure of MC comparing H to N, should be equal to ECcost1H

cap drop W_tot_*
cap drop PrH_*
cap drop AC_*
cap drop MC_*
cap drop W_tot_alt_*
cap drop PrH_alt_*
cap drop AC_alt_*
cap drop MC_*

//Outer loop: Price. Inner loop: sum over epsilon.

//forvalues P=0(10)1000{
forvalues P=$MIN($STEP)$MAX{

	cap drop sum_H
	cap drop sum_MC
	cap drop sum_W
	cap drop sum_altH
	cap drop sum_altMC
	cap drop sum_altW
		
	quiet gen sum_H = 0
	quiet gen sum_MC = 0
	quiet gen sum_W = 0 	//comparing H to L
	quiet gen sum_altH = 0
	quiet gen sum_altMC = 0
	quiet gen sum_altW = 0	//comparing H to nothing

	di "Price: " `P'
	
	//Generate plan choice conditional on epsilon realization
	
	local R = 200
	forvalues i=1(1)`R'{
		*want Pr always to lie btwn 0 and 1, (thus cant have it equal Q/Q or 0/Q)
		local Pr = `i'/`R' - 1/(2*`R')
	
		quiet replace sum_H = sum_H + 1 if `P' - coeff_eps*invnormal(`Pr') < utilityH
		cap drop temp_chooseH
		quiet gen temp_chooseH = 0
		quiet replace temp_chooseH = 1 if `P' - coeff_eps*invnormal(`Pr') < utilityH
		
		quiet replace sum_MC = sum_MC + Ecost1diff1 if temp_chooseH == 1
		quiet replace sum_MC = sum_MC + 0 if temp_chooseH == 0

		quiet replace sum_altH = sum_altH + 1 if `P' - coeff_alt_eps*invnormal(`Pr') < utilityAltH
		cap drop temp_choosealtH
		quiet gen temp_choosealtH = 0
		quiet replace temp_choosealtH = 1 if `P' - coeff_alt_eps*invnormal(`Pr') < utilityAltH
		
		quiet replace sum_altMC = sum_altMC + Ecost1diff2 if temp_choosealtH == 1
		quiet replace sum_altMC = sum_altMC + 0 if temp_choosealtH == 0

		//welfare is the diff between CE and cost
		//-1/gamma * exp(-gamma*CE) = -1/gamma * exp(-gamma*OOPj) \equiv  -1/gamma * Wj
		//implies CE = ln(Wj)/-gamma
		//recall WH = exp(-gamma*W)  = - utility*gamma
		quiet replace sum_W = sum_W + (ln(WH)/(-coeff_gamma) + coeff_eps*invnormal(`Pr') - Ecost1H) if temp_chooseH == 1
		quiet replace sum_W = sum_W + (ln(WL)/(-coeff_gamma) - Ecost1L) if temp_chooseH == 0

		quiet replace sum_altW = sum_altW + (ln(WH)/(-coeff_gamma) + coeff_alt_eps*invnormal(`Pr') - Ecost1H) if temp_choosealtH == 1
		quiet replace sum_altW = sum_altW + (ln(WN)/(-coeff_gamma) - Ecost1N) if temp_chooseH == 0

	}
	
	//demand curve
	gen PrH_`P' = sum_H/(`R')
	label var PrH_`P' "Pr choose H | deltaPrice = `P'"
	
	//mc curve (probabilistic in the same way as demand)
	gen MC_`P' = sum_MC/(`R')
	label var MC_`P' "(MC of choose H | deltaPrice = `P') = Ecost1*PrH"	
	
	gen W_tot_`P' = sum_W/(`R')
	label var W_tot_`P' "(Total surplus | deltaPrice = `P') = (WH-WL)*PrH"
	
	
	
	//demand curve
	gen PrH_alt_`P' = sum_altH/(`R')
	label var PrH_alt_`P' "Pr choose altH | deltaPrice = `P'"
	
	//mc curve (probabilistic in the same way as demand)
	gen MC_alt_`P' = sum_altMC/(`R')
	label var MC_alt_`P' "(MC of choose altH | deltaPrice = `P') = Ecostdiff2*PrHalt"	
	
	gen W_tot_alt_`P' = sum_altW/(`R')
	label var W_tot_alt_`P' "(Total surplus | deltaPrice = `P') = (WH-WN)*PrHalt"
}

/**********************************************************************************
***********************************************************************************

Figure A3: Simulated plan choices at assumed price

***********************************************************************************
**********************************************************************************/

cap drop ln_predtot
gen ln_predtot = ln(predtot)

			quiet summ ln_predtot if sample==1 & ag2==1, d
			scalar min_1 = r(p1)
			scalar max_1 = r(p99)
			
			quiet summ ln_predtot if sample==1 & ag2==2, d
			scalar min_2 = r(p1)
			scalar max_2 = r(p99)
			
			quiet summ ln_predtot  if sample==1 & ag2==3, d
			scalar min_3 = r(p1)
			scalar max_3 = r(p99)
		
			quiet summ ln_predtot  if sample==1 & ag2==4, d
			scalar min_4 = r(p1)
			scalar max_4 = r(p99)

twoway (lpoly PrH_695 ln_predtot if plan=="B" & ag2==1 & ln_predtot>=min_1 & ln_predtot<max_1, bwidth(.4) lcolor(maroon) lpattern(dash) lwidth(medthick)) ///
		(lpoly PrH_695 ln_predtot if plan=="B" & ag2==2 & ln_predtot>=min_2 & ln_predtot<max_2 ,bwidth(.4) lcolor(dkorange) lpattern(..-) lwidth(medthick)) ///
		(lpoly PrH_695 ln_predtot if plan=="B" & ag2==3 & ln_predtot>=min_3 & ln_predtot<max_3 ,bwidth(.4) lpattern(shortdash) lwidth(medthick)) ///
		(lpoly PrH_695 ln_predtot if plan=="B" & ag2==4 & ln_predtot>=min_4 & ln_predtot<max_4 ,bwidth(.4) lcolor(gs10) lpattern(solid) lwidth(medthick)), ///
		xtitle("expected costs, {it:C}{subscript:i}") xlabel(6.2 "$500" 6.9 "$1000" 7.6 "$2k" 8.29 "$4k" 8.99 "$8k" 9.68 "$16k" 10.37 "$32k", grid)  ///
		ytitle("Chose Plan {it:H}") ylabel(.1(.1).7) ///
		legend(label(1 "18-29") label(2 "30-39") label(3 "40-49") label(4 "50-59") row(2) ring(0) position(5) bmargin(medium)) ///
		graphregion(color(white)) aspectratio(1)


graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'SIMPlanChoice_total_695.eps", replace
graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'SIMPlanChoice_total_695.pdf", replace

*/

/**********************************************************************************
***********************************************************************************

Simulate Counterfactual Choices under new prices

***********************************************************************************
**********************************************************************************/

global MIN = 80
global MAX = 500
global STEP = 10


//Ecost1diff1 = the correct measure of MC comparing H to L
//Ecost1diff2 =the correct measure of MC comparing H to N, should be equal to ECcost1H

cap drop W_tot_*
cap drop PrH_*
cap drop AC_*
cap drop MC_*
cap drop W_tot_alt_*
cap drop PrH_alt_*
cap drop AC_alt_*
cap drop MC_*

//Outer loop: Price. Inner loop: sum over epsilon.

//forvalues P=0(10)1000{
forvalues P=$MIN($STEP)$MAX{

	cap drop sum_H
	cap drop sum_MC
	cap drop sum_W
	cap drop sum_altH
	cap drop sum_altMC
	cap drop sum_altW
		
	quiet gen sum_H = 0
	quiet gen sum_MC = 0
	quiet gen sum_W = 0 	//comparing H to L
	quiet gen sum_altH = 0
	quiet gen sum_altMC = 0
	quiet gen sum_altW = 0	//comparing H to nothing

	di "Price: " `P'
	
	//Generate plan choice conditional on epsilon realization
	local R = 200
	forvalues i=1(1)`R'{
		*want Pr always to lie btwn 0 and 1, (thus cant have it equal Q/Q or 0/Q)
		local Pr = `i'/`R' - 1/(2*`R')
	
		quiet replace sum_H = sum_H + 1 if `P' - coeff_eps*invnormal(`Pr') < utilityH
		cap drop temp_chooseH
		quiet gen temp_chooseH = 0
		quiet replace temp_chooseH = 1 if `P' - coeff_eps*invnormal(`Pr') < utilityH
		
		quiet replace sum_MC = sum_MC + Ecost1diff1 if temp_chooseH == 1
		quiet replace sum_MC = sum_MC + 0 if temp_chooseH == 0

		quiet replace sum_altH = sum_altH + 1 if `P' - coeff_alt_eps*invnormal(`Pr') < utilityAltH
		cap drop temp_choosealtH
		quiet gen temp_choosealtH = 0
		quiet replace temp_choosealtH = 1 if `P' - coeff_alt_eps*invnormal(`Pr') < utilityAltH
		
		quiet replace sum_altMC = sum_altMC + Ecost1diff2 if temp_choosealtH == 1
		quiet replace sum_altMC = sum_altMC + 0 if temp_choosealtH == 0

		//welfare is the diff between CE and cost
		//-1/gamma * exp(-gamma*CE) = -1/gamma * exp(-gamma*OOPj) \equiv  -1/gamma * Wj
		//implies CE = ln(Wj)/-gamma
		//recall WH = exp(-gamma*W)  = - utility*gamma
		quiet replace sum_W = sum_W + (ln(WH)/(-coeff_gamma) + coeff_eps*invnormal(`Pr') - Ecost1H) if temp_chooseH == 1
		quiet replace sum_W = sum_W + (ln(WL)/(-coeff_gamma) - Ecost1L) if temp_chooseH == 0

		quiet replace sum_altW = sum_altW + (ln(WH)/(-coeff_gamma) + coeff_alt_eps*invnormal(`Pr') - Ecost1H) if temp_choosealtH == 1
		quiet replace sum_altW = sum_altW + (ln(WN)/(-coeff_gamma) - Ecost1N) if temp_chooseH == 0

	}
	
	//demand curve
	gen PrH_`P' = sum_H/(`R')
	label var PrH_`P' "Pr choose H | deltaPrice = `P'"
	
	//mc curve (probabilistic in the same way as demand)
	gen MC_`P' = sum_MC/(`R')
	label var MC_`P' "(MC of choose H | deltaPrice = `P') = Ecost1*PrH"	
	
	gen W_tot_`P' = sum_W/(`R')
	label var W_tot_`P' "(Total surplus | deltaPrice = `P') = (WH-WL)*PrH"
	
	
	
	//demand curve
	gen PrH_alt_`P' = sum_altH/(`R')
	label var PrH_alt_`P' "Pr choose altH | deltaPrice = `P'"
	
	//mc curve (probabilistic in the same way as demand)
	gen MC_alt_`P' = sum_altMC/(`R')
	label var MC_alt_`P' "(MC of choose altH | deltaPrice = `P') = Ecostdiff2*PrHalt"	
	
	gen W_tot_alt_`P' = sum_altW/(`R')
	label var W_tot_alt_`P' "(Total surplus | deltaPrice = `P') = (WH-WN)*PrHalt"
}



/**********************************************************************************
***********************************************************************************

Demand and AC

***********************************************************************************
**********************************************************************************/


//Keep just one observation per person year
keep if planB==1
keep if sample==1

cap drop Demand*
cap drop plotMC*

matrix A = J(200,2,-1)
matrix DMat = J(200,5,-1)
matrix C = J(200,20,-1)
matrix DMatalt = J(200,12,-1)
matrix Calt = J(200,20,-1)
matrix W= J(200,7,-1)
matrix Walt= J(200,7,-1)

local max = ($MAX-$MIN)/$STEP
forvalues i=1(1)`max'{

	local p = `i'*$STEP + $MIN  
	//local p = `i'*10 + 2000
	//local p = `i'*10
	di "Price: " `p'
	//local pminus1 = `p' - 10
	local pminus1 = `p' - 5
		
	//counters
	matrix A[`i', 1] = `i'

	//price
	matrix A[`i', 2] = `p'

	//Pr(H)	 assign to local var and to a var in the dataset
	quiet summ PrH_`p' if sample==1 
	matrix DMat[`i', 1] = r(mean)
	quiet gen Demand_`p' = r(mean) if sample==1 
	quiet summ PrH_alt_`p' if sample==1 
	matrix DMatalt[`i', 1] = r(mean)


	//sample some obs to plot MC. Weight by Pr of H
	quiet gsample 50 [aw=PrH_`p'], gen(plotMC_`p') wor
	
	local counter = 2
	foreach age in 1 2 3 4{
		quiet summ PrH_`p'  if sample==1  & ag2==`age'
		matrix DMat[`i', `counter'] = r(mean)
		quiet gen Demand_age`age'_`p' = r(mean) if sample==1 & ag2==`age'

		quiet summ PrH_alt_`p'  if sample==1  & ag2==`age'
		matrix DMatalt[`i', `counter'] = r(mean)

		//sample some obs to plot MC. Weight by Pr of H
		quiet gsample 50 [aw=PrH_`p'] if ag2==`age', gen(plotMC_age`age'_`p') wor

		local counter = `counter' +1
	}
	
	//Welfare
	quiet summ W_tot_`p' if sample==1
	matrix W[`i', 1] = r(mean)
	quiet summ W_tot_alt_`p' if sample==1
	matrix Walt[`i', 1] = r(mean)

	local counter = 2
	foreach age in 1 2 3 4{
		quiet summ  W_tot_`p' if sample==1 & ag2==`age'
		matrix W[`i', `counter'] = r(mean)

		quiet summ  W_tot_alt_`p' if sample==1 & ag2==`age'
		matrix Walt[`i', `counter'] = r(mean)
		
		local counter = `counter' +1
	}
	foreach fem in 0 1{
		quiet summ  W_tot_`p' if sample==1 & fem==`fem'
		matrix W[`i', `counter'] = r(mean)

		quiet summ  W_tot_alt_`p' if sample==1 & fem==`fem'
		matrix Walt[`i', `counter'] = r(mean)
		
		local counter = `counter' +1
	}
}

matrix list W
matrix list Walt


//save table as dta file
preserve

drop*
foreach matrix in W Walt A DMat DMatalt C Calt{
	cap drop `matrix'*
	svmat `matrix'
}
keep in 1/101
save "$WORK/Data/SimMatrices_$MIN-$STEP-$MAX.dta", replace

restore




/**********************************************************************************
***********************************************************************************

Simulate Counterfactual Choices under new prices

***********************************************************************************
**********************************************************************************/

global MIN = 0
global MAX = 1500
global STEP = 100


//Ecost1diff1 = the correct measure of MC comparing H to L
//Ecost1diff2 =the correct measure of MC comparing H to N, should be equal to ECcost1H

cap drop W_tot_*
cap drop PrH_*
cap drop AC_*
cap drop MC_*
cap drop W_tot_alt_*
cap drop PrH_alt_*
cap drop AC_alt_*
cap drop MC_*

//Outer loop: Price. Inner loop: sum over epsilon.

//forvalues P=0(10)1000{
forvalues P=$MIN($STEP)$MAX{

	cap drop sum_H
	cap drop sum_MC
	cap drop sum_W
	cap drop sum_altH
	cap drop sum_altMC
	cap drop sum_altW
		
	quiet gen sum_H = 0
	quiet gen sum_MC = 0
	quiet gen sum_W = 0 	//comparing H to L
	quiet gen sum_altH = 0
	quiet gen sum_altMC = 0
	quiet gen sum_altW = 0	//comparing H to nothing

	di "Price: " `P'
	
	//Generate plan choice conditional on epsilon realization
	local R = 200
	forvalues i=1(1)`R'{
		*want Pr always to lie btwn 0 and 1, (thus cant have it equal Q/Q or 0/Q)
		local Pr = `i'/`R' - 1/(2*`R')
	
		quiet replace sum_H = sum_H + 1 if `P' - coeff_eps*invnormal(`Pr') < utilityH
		cap drop temp_chooseH
		quiet gen temp_chooseH = 0
		quiet replace temp_chooseH = 1 if `P' - coeff_eps*invnormal(`Pr') < utilityH
		
		quiet replace sum_MC = sum_MC + Ecost1diff1 if temp_chooseH == 1
		quiet replace sum_MC = sum_MC + 0 if temp_chooseH == 0

		quiet replace sum_altH = sum_altH + 1 if `P' - coeff_alt_eps*invnormal(`Pr') < utilityAltH
		cap drop temp_choosealtH
		quiet gen temp_choosealtH = 0
		quiet replace temp_choosealtH = 1 if `P' - coeff_alt_eps*invnormal(`Pr') < utilityAltH
		
		quiet replace sum_altMC = sum_altMC + Ecost1diff2 if temp_choosealtH == 1
		quiet replace sum_altMC = sum_altMC + 0 if temp_choosealtH == 0

		//welfare is the diff between CE and cost
		//-1/gamma * exp(-gamma*CE) = -1/gamma * exp(-gamma*OOPj) \equiv  -1/gamma * Wj
		//implies CE = ln(Wj)/-gamma
		//recall WH = exp(-gamma*W)  = - utility*gamma
		quiet replace sum_W = sum_W + (ln(WH)/(-coeff_gamma) + coeff_eps*invnormal(`Pr') - Ecost1H) if temp_chooseH == 1
		quiet replace sum_W = sum_W + (ln(WL)/(-coeff_gamma) - Ecost1L) if temp_chooseH == 0

		quiet replace sum_altW = sum_altW + (ln(WH)/(-coeff_gamma) + coeff_alt_eps*invnormal(`Pr') - Ecost1H) if temp_choosealtH == 1
		quiet replace sum_altW = sum_altW + (ln(WN)/(-coeff_gamma) - Ecost1N) if temp_chooseH == 0

	}
	
	//demand curve
	gen PrH_`P' = sum_H/(`R')
	label var PrH_`P' "Pr choose H | deltaPrice = `P'"
	
	//mc curve (probabilistic in the same way as demand)
	gen MC_`P' = sum_MC/(`R')
	label var MC_`P' "(MC of choose H | deltaPrice = `P') = Ecost1*PrH"	
	
	gen W_tot_`P' = sum_W/(`R')
	label var W_tot_`P' "(Total surplus | deltaPrice = `P') = (WH-WL)*PrH"
	
	
	
	//demand curve
	gen PrH_alt_`P' = sum_altH/(`R')
	label var PrH_alt_`P' "Pr choose altH | deltaPrice = `P'"
	
	//mc curve (probabilistic in the same way as demand)
	gen MC_alt_`P' = sum_altMC/(`R')
	label var MC_alt_`P' "(MC of choose altH | deltaPrice = `P') = Ecostdiff2*PrHalt"	
	
	gen W_tot_alt_`P' = sum_altW/(`R')
	label var W_tot_alt_`P' "(Total surplus | deltaPrice = `P') = (WH-WN)*PrHalt"
}



/**********************************************************************************
***********************************************************************************

Plot Demand and AC

***********************************************************************************
**********************************************************************************/


*----find marginal changes in Pr(H) for changes in P
/*
cap drop dPrH_*
forvalues P=210(10)800{
	local last = `P' - 10
	gen dPrH_`P' =  PrH_`last' - PrH_`P'
	label var dPrH_`P' "dPr(choose H0/d(deltaPrice|P=`last',`P')"
}
*/


//Keep just one observation per person year
keep if planB==1
keep if sample==1

cap drop Demand*
cap drop plotMC*

matrix A = J(200,2,-1)
matrix DMat = J(200,5,-1)
matrix C = J(200,20,-1)
matrix DMatalt = J(200,12,-1)
matrix Calt = J(200,20,-1)
matrix W= J(200,7,-1)
matrix Walt= J(200,7,-1)

local max = ($MAX-$MIN)/$STEP
forvalues i=1(1)`max'{

	local p = `i'*$STEP + $MIN  
	//local p = `i'*10 + 2000
	//local p = `i'*10
	di "Price: " `p'
	//local pminus1 = `p' - 10
	local pminus1 = `p' - 5
		
	//counters
	matrix A[`i', 1] = `i'

	//price
	matrix A[`i', 2] = `p'

	//Pr(H)	 assign to local var and to a var in the dataset
	quiet summ PrH_`p' if sample==1 
	matrix DMat[`i', 1] = r(mean)
	quiet gen Demand_`p' = r(mean) if sample==1 
	quiet summ PrH_alt_`p' if sample==1 
	matrix DMatalt[`i', 1] = r(mean)


	//sample some obs to plot MC. Weight by Pr of H
	quiet gsample 50 [aw=PrH_`p'], gen(plotMC_`p') wor
	
	local counter = 2
	foreach age in 1 2 3 4{
		quiet summ PrH_`p'  if sample==1  & ag2==`age'
		matrix DMat[`i', `counter'] = r(mean)
		quiet gen Demand_age`age'_`p' = r(mean) if sample==1 & ag2==`age'

		quiet summ PrH_alt_`p'  if sample==1  & ag2==`age'
		matrix DMatalt[`i', `counter'] = r(mean)

		//sample some obs to plot MC. Weight by Pr of H
		quiet gsample 50 [aw=PrH_`p'] if ag2==`age', gen(plotMC_age`age'_`p') wor

		local counter = `counter' +1
	}
	
	//Welfare
	quiet summ W_tot_`p' if sample==1
	matrix W[`i', 1] = r(mean)
	quiet summ W_tot_alt_`p' if sample==1
	matrix Walt[`i', 1] = r(mean)

	local counter = 2
	foreach age in 1 2 3 4{
		quiet summ  W_tot_`p' if sample==1 & ag2==`age'
		matrix W[`i', `counter'] = r(mean)

		quiet summ  W_tot_alt_`p' if sample==1 & ag2==`age'
		matrix Walt[`i', `counter'] = r(mean)
		
		local counter = `counter' +1
	}
	foreach fem in 0 1{
		quiet summ  W_tot_`p' if sample==1 & fem==`fem'
		matrix W[`i', `counter'] = r(mean)

		quiet summ  W_tot_alt_`p' if sample==1 & fem==`fem'
		matrix Walt[`i', `counter'] = r(mean)
		
		local counter = `counter' +1
	}
			
}

matrix list W
matrix list Walt
*matrix list A




/**********************************************************************************
***********************************************************************************

Plot Demand and AC

***********************************************************************************
**********************************************************************************/

foreach matrix in W Walt A DMat DMatalt C Calt{
	cap drop `matrix'*
	svmat `matrix'
}

//Create Analogs to Figure 4

local max =13
twoway 	(scatter A2 DMat2 in 1/`max', connect(l) lpattern(solid) lcolor(maroon) msymbol(none) lwidth(thick) ) ///
  		(scatter A2 DMat5 in 1/`max', connect(l) lpattern(solid) lcolor(gs10) msymbol(none) lwidth(thick) ) ///
	 	/*(scatter C2 DMat2 in 1/`max', connect(l) lpattern(solid) lcolor(maroon) msymbol(none) lwidth(thick)) */ ///
	 	/*(scatter C5 DMat5 in 1/`max', connect(l) lpattern(solid) lcolor(eltblue) msymbol(none) lwidth(thick)) */ , ///
		graphregion(color(white)) bgcolor(white) ///
		xtitle("Q{sub:H}") xlabel(  .1 ".10" .2 ".20" .3 ".30" .4 ".40" .5 ".50" .6 "60" ,nogrid) ylabel(500 "$500" 1000 "$1000" 1500 "$1500",nogrid) ///
		ytitle("Price, P{sub:H}-P{sub:L}") ///
 		name(d1, replace) saving("$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'DemandHetero_1.gph", replace) ///
		legend(off) 

forvalues p=100(100)1300{
	graph addplot scatter Ecost1diff1 Demand_age4_`p' if plotMC_age4_`p', jitter(10) mlwidth(vvthin) mcolor(gs10) msymbol(oh) msize(medium) nodraw
}

forvalues p=100(100)1100{
	graph addplot scatter Ecost1diff1 Demand_age1_`p' if plotMC_age1_`p', jitter(10) mcolor(maroon) msymbol(o) msize(small) nodraw
}
	graph addplot scatter Ecost1diff1 Demand_age1_1200 if plotMC_age1_1200, jitter(10) mcolor(maroon) msymbol(o) msize(small)
graph export "$WORK`c(dirsep)'Results2016`c(dirsep)'Figures`c(dirsep)'DemandHetero_1.pdf", replace 
 
 
 

