
/*
nohup nice  stata -b do Simulation-2016-5-16 &
*/
*----------------------------------------------------
*----------------------------------------------------
* Load data
*----------------------------------------------------
*----------------------------------------------------


clear
clear mata
clear matrix
set mem 6g
set more off

global SOURCE "/disk/aging/medstat/data/sas"
global BULK "/disk/agebulk2/medstat.work/gerusom"
global WORK "/disk/agedisk3/medstat.work/gerusom"
global SCRATCH "/disk/agescratch4/gerusom"

global DISTR "/disk/agedisk3/medstat.work/gerusom/Results/Distr"

sysdir set PERSONAL "/disk/homes2b/nber/gerusom/ado/plus/personal"

use "$WORK/Data/Cleaned_merged_MAY072011.dta", clear


local year = 2006
keep if year==`year'
keep if count_fam==1


*----------------------------------------------------
*----------------------------------------------------
* Find parameters of individual-specific OOP distribution
*----------------------------------------------------
*----------------------------------------------------

*----Create residual between expected and realized

gen pred_err = totdoc - preddoc


*----------------------------------------------------
*----------------------------------------------------
*----Group enrollees into cells by age/sex?/predicted use
*----------------------------------------------------
*----------------------------------------------------

cap drop sample
gen sample = 1 if preddoc~=.

cap drop cell_grp
cap drop cellgrp_*
gen cell_grp = .
label var cell_grp "group id, with value = 1000 + 100*`age'+ 1*bottom decile of cell"

forvalues age=1(1)4{
	
	*----find modal value of preddoc that corresponds to the lower bound of the prediction
	*----necessary because this value may be the value of pctile(1)-pctile(30) and we need to know to create bins
	
	_pctile preddoc if ag2==`age' & sample==1, percentiles(10)
	cap drop temp*
	di r(r10)
	gen temp_p10 = r(r1)
	
	count if ag2==`age' & sample==1 & preddoc<(temp_p10 + .01)
	local temp_num = r(N)
	count if ag2==`age' & sample==1
	local temp_den = r(N)
	local temp_fract= `temp_num'/`temp_den'
	

	*----Find Deciles
	*round fraction to next highest pctile - this will be the first pctile of interest.
	*if fraction is more than halfway to next pctile, lump the remaining fraction of pctile into the next cell
	
	local temp_ceil = ceil(10*`temp_fract')
	di `temp_fract'
	di `temp_ceil'

	local temp_collapse_up = (`temp_ceil' - 10*`temp_fract' < .5) //less than half the pctile is higher than the p10 value
	di `temp_collapse_up'
	
	local first_cellmax_pctile = `temp_ceil' + `temp_collapse_up'
	local first_cellmax_pctileminus1 = `first_cellmax_pctile' - 1
	
	
	cap drop pct
	pctile pct = preddoc if ag2==`age' & sample==1, nq(10)
	list pct in 1/9
	_pctile  preddoc if ag2==`age' & sample==1, percentiles(10(10)90)
	return list
	
	*----Assign people to age x decile groups, lumping bottom groups together if the first few deciles are identical
	
	*handle the (0-x] cell, the (x,firstcellmax] and (90,100] groups separately
	local pctile9 = pct in 9
	local pctilex = pct in `first_cellmax_pctile'

	
	replace cell_grp = 1000 + 100*`age'+ 1*0  				if ag2==`age' & (preddoc<(temp_p10 + .01)) & sample==1
	replace cell_grp = 1000 + 100*`age'+ 1*(`first_cellmax_pctile'-1)  	if ag2==`age' & (preddoc>=(temp_p10 + .01)) & preddoc<`pctilex' & sample==1
	replace cell_grp = 1000 + 100*`age'+ 1*9  				if ag2==`age' & preddoc>=`pctile9' & sample==1
	
	gen cellgrp_`age'_0 = 0
	gen cellgrp_`age'_`first_cellmax_pctileminus1' = 0
	gen cellgrp_`age'_9 = 0

	replace cellgrp_`age'_0 = 1 				if ag2==`age' & (preddoc<(temp_p10 + .01)) & sample==1
	replace cellgrp_`age'_`first_cellmax_pctileminus1'= 1  	if ag2==`age' & (preddoc>=(temp_p10 + .01)) & preddoc<`pctilex' & sample==1
	replace cellgrp_`age'_9  = 1				if ag2==`age' & preddoc>=`pctile9' & sample==1

	
	forvalues pctile=`first_cellmax_pctile'(1)8{
	
		local cellmin = pct in `pctile'
		local next = `pctile' + 1
		local cellmax = pct in `next'
		
		replace cell_grp = 1000 + 100*`age'+ 1*`pctile' if ag2==`age' & (preddoc>=`cellmin') & (preddoc<`cellmax') & sample==1
		
		gen cellgrp_`age'_`pctile' = 0
		replace cellgrp_`age'_`pctile' = 1 if ag2==`age' & (preddoc>=`cellmin') & (preddoc<`cellmax') & sample==1
	}
	

}

*----Make sure that deciles look correct, including the larger bottom quantile
ta cell_grp if ag2==1 & sample==1, mis
ta cell_grp if ag2==2 & sample==1, mis
ta cell_grp if ag2==3 & sample==1, mis
ta cell_grp if ag2==4 & sample==1, mis

*----Make sure everyone with a predicted use is in one and only one group
egen check_multicell_membership = rowtotal(cellgrp_1_0-cellgrp_1_8 cellgrp_2_0-cellgrp_2_8 cellgrp_3_0-cellgrp_3_8 cellgrp_4_0-cellgrp_4_8)
ta check_multicell_membership, mis
count if check_multicell_membership==0 & age<60 & age>=18 & preddoc~=.


*----------------------------------------------------
*----------------------------------------------------
*----Parameterize distribution within cell
*----------------------------------------------------
*----------------------------------------------------

*----FIND THE MASS AT ZERO

cap drop Pr_zero
gen Pr_zero = .

cap drop sample
gen sample=1 if preddoc~=.

forvalues age=1(1)4{
	forvalues pctile=0(1)9{
		local group = 1000+100*`age' + 1*`pctile' 
		quiet count if cell_grp==`group'
		if r(N)>0{
				
			count if cell_grp==`group' & sample==1 & totdoc==0
			local temp_num = r(N)
			count if cell_grp==`group' & sample==1 & totdoc>=0 & totdoc~=.
			local temp_den = r(N)
			local temp_fract= `temp_num'/`temp_den'	
			
			replace Pr_zero = `temp_fract' if cell_grp==`group'
		
			di "group: " `group'
			di "fraction with zero realized use: " `temp_fract'
						 
		}
	}
}


*----LOGNORMAL ML ESTIMATION

*----Estimate distribution of realized cost within cell by ML
*----Find parameters of lnnormal

cap drop lntotdoc
gen lntotdoc = ln(totdoc)

cap drop sample
gen sample = 1 if totdoc>0 & preddoc~=.

cap drop lnN_*
gen lnN_u = .
gen lnN_sig2 = .
gen lnN_mean = .

label var lnN_u "lnNorm location parameter within decile-age cell"
label var lnN_sig2 "lnNorm variance parameter within decile-age cell"
label var lnN_mean "lnNorm implied mean within decile-age cell; zero mass not included"

forvalues age=1(1)4{
	forvalues pctile=0(1)9{
		local group = 1000+100*`age' + 1*`pctile' 
		quiet count if cell_grp==`group'
		if r(N)>0{

			quiet summ lntotdoc if cell_grp==`group' & sample==1
			
			replace lnN_u = r(mean) if cell_grp==`group'
			replace lnN_sig2 = r(Var) if cell_grp==`group'
			replace lnN_mean = exp(lnN_u + lnN_sig2/2) if cell_grp==`group'
		
			di "group: " `group'
			di "from lnN: " exp(r(mean) + r(Var)/2)
			quiet summ totdoc if cell_grp==`group' & sample==1
			di "actual mean: " r(mean)
			
		}
	}
}


*----------------------------------------------------
*----------------------------------------------------
*----Adjust mu parameter at the individual level so that expectation of distribution matches ACG prediction
*----------------------------------------------------
*----------------------------------------------------

cap drop temp_lnpreddoc 
gen temp_preddoc = preddoc
replace temp_preddoc = 100 if preddoc==0

*add c = ln(ACG/(1-prZero)) - u - sig2/2  to u so that ACG = (1-prZero)exp(u + c + sig2/2) = (1-prZero)exp(ln(ACG/(1-prZero)))) = ACG

cap drop lnN_adj_*
gen lnN_adj_u = lnN_u + ( ln(temp_preddoc/(1-Pr_zero)) - lnN_u - lnN_sig2/2)
gen lnN_adj_mean = (1-Pr_zero)*exp(lnN_adj_u + lnN_sig2/2)
gen lnN_sig = sqrt(lnN_sig2)


label var lnN_adj_u "lnNorm location parameter--adjusted to match ACG prediction"
label var lnN_sig "lnNorm sd parameter within decile-age cell"
label var lnN_adj_mean "lnNorm implied mean--adjusted to match ACG prediction, zero mass included"


compare lnN_adj_mean preddoc


*----------------------------------------------------
*----------------------------------------------------
* Create new vars for reshape for structural estimation and sim
*----------------------------------------------------
*----------------------------------------------------


gen ided_A =.
gen ided_B =.
gen ided_N =.
replace ided_A = 500 if year>=2005 & year<=2007
replace ided_B = 300 if year>=2005 & year<=2007
replace ided_N = 10000000 if year>=2005 & year<=2007
 
gen coins_A =.
gen coins_B =.
gen coins_N =.
replace coins_A = .20 if year>=2005 & year<=2007
replace coins_B = .10 if year>=2005 & year<=2007 
replace coins_N = 1.0 if year>=2005 & year<=2007 

gen ioop_A =4250
gen ioop_B =2300
gen ioop_N =10000000

*----------------------------------------------------
*----------------------------------------------------
*----RESHAPE
*----------------------------------------------------
*----------------------------------------------------


reshape long OOP_ ided_ coins_ ioop_, i(patient_id) j(plan) string

cap drop sample
gen sample=1 if preddoc~=. & lnN_u~=. & emprel==1 & count_fam==1 
count if lnN_u~=. & preddoc==.

keep if sample==1

*----------------------------------------------------
*----------------------------------------------------
*----Create some indicators and placeholder variables for structural estimator - some of these values are irrelevant!!
*----------------------------------------------------
*----------------------------------------------------

gen epsilon_B = 0
replace epsilon_B = uniform() if plan=="B"
*label var epsilon_B "placeholder only-contains no real data"

gen gamma = uniform()
*label var gamma "placeholder only-contains no real data"

*----Create some indicator variables for structural estimator - dummies interacted with plan

gen agegrp1 = 0
replace agegrp1 = 1 if ag2==1 & plan=="B"
label var agegrp1 "age 18-29"

gen agegrp2 = 0
replace agegrp2 = 1 if ag2==2 & plan=="B"
label var agegrp2 "age 30-39"

gen agegrp3 = 0
replace agegrp3 = 1 if ag2==3 & plan=="B"
label var agegrp3 "age 40-49"

gen agegrp4 = 0
replace agegrp4 = 1 if ag2==4 & plan=="B"
label var agegrp4 "age 50-59"

gen planB = 0
replace planB = 1 if plan=="B"

gen female = 0
replace female = 1 if fem==1 & plan=="B"
label var female "interaction fem x B"

gen lnpred = ln(preddoc)

gen ln_se = 1


*----------------------------------------------------
*----Find Avg Cost TO EMPLOYER in group

*1. find utilization, with drugs separate
*2. convert it to the employer payment using OOP rules, and using actual employer payments for drugs, since these dont differ by plans
*3. find avg cost to employer conditional on the plan chosen, (real or cf)


*find non-drug and drug utilization
gen non_drug = out_totpay + in_totpay
gen employer_drug = pharm_totpay - pharm_deduct - pharm_copay - pharm_coins
compare totdoc non_drug //same

cap drop employer_cost
gen employer_cost = .
label var employer_cost "total cost to employer of enrolling patient"

*----find predicted cost difference between H and L associated with each enrollee
cap drop pred_employer_cost
gen pred_employer_cost = .
label var pred_employer_cost "predicted cost to employer of enrolling patient (no drug)"


/**********************************************************************************

Sample and new employer and consumer cost vars

**********************************************************************************/

//Define person and plan cost differentials

//Person Expected OOP 2 (expectation of OOP costs)
//Put expected cost through the coinsurance/deductible formula and get enrollee OOP cost
cap drop temp*
cap drop EOOP2*
gen EOOP2 = preddoc if preddoc<ided_ & sample==1
replace EOOP2 = (preddoc - ided_)*coins_ + ided_ if preddoc>=ided_ & sample==1
replace EOOP2 = ioop_ if EOOP2>ioop_ & EOOP2~=. & sample==1
label var EOOP2 "OOP of expected non-drug costs"
egen temp1 = max(EOOP2) if plan=="B", by(enrolid year)
egen EOOP2H = max(temp1), by(enrolid year)
label var EOOP2H "H OOP of expected costs; ignore concavity of cost sharing"
egen temp2 = max(EOOP2) if plan=="A", by(enrolid year)
egen EOOP2L = max(temp2), by(enrolid year)
label var EOOP2L "L OOP of expected costs; ignore concavity of cost sharing"
egen temp3 = max(EOOP2) if plan=="N", by(enrolid year)
egen EOOP2N = max(temp3), by(enrolid year)
label var EOOP2N "N OOP of expected costs; ignore concavity of cost sharing"


//Plan Expected spending
//Put expected cost through the coinsurance/deductible formula and get employer expected cost; ignores concavity of cost sharing
cap drop temp*
cap drop Ecost2*
gen Ecost2 = pred_employer_cost
egen temp1 = max(Ecost2) if plan=="B", by(enrolid year)
egen Ecost2H = max(temp1), by(enrolid year)
label var Ecost2H "H Employer expected costs; ignore concavity of cost sharing"
egen temp2 = max(Ecost2) if plan=="A", by(enrolid year)
egen Ecost2L = max(temp2), by(enrolid year)
label var Ecost2L "L Employer expected costs; ignore concavity of cost sharing"
egen temp3 = max(Ecost2) if plan=="N", by(enrolid year)
egen Ecost2N = max(temp3), by(enrolid year)
label var Ecost2N "N Employer expected costs; ignore concavity of cost sharing"

//Check that the total predicted spending sums correctly
cap drop checksum_preddoc
gen checksum_preddoc = Ecost2 + EOOP2
compare checksum_preddoc preddoc // the employer and employee portion of predicted spending should sum to the total prediction

//Do expected OOP spending correctly: Take average of OOP over the distribution of outcomes
//Distribution of medical cost risk
cap drop use_*
cap drop oop_*
cap drop emp_*
cap drop sum_oop
cap drop sum_employer
cap drop sum_use
gen double sum_oop = 0
gen double sum_employer = 0
gen double sum_use = 0
local Q = 200
forvalues i=1(1)`Q'{
	//want Pr always to lie btwn 0 and 1, otherwise invnormal is infinite, (thus cant have it equal Q/Q or 0/Q)
	local Pr = `i'/`Q' - 1/(2*`Q')
	//
	quiet gen use_`i' = exp(lnN_u + lnN_sig*invnormal(`Pr'))
	//enrollee OOP costs	
	quiet gen double oop_`i' = use_`i' if use_`i'<ided_
	quiet replace oop_`i' = ided_ + (use_`i'-ided_)*coins_ if use_`i'>ided_ & use_`i'~=.
	quiet replace oop_`i' = ioop_ if oop_`i'>ioop_ & use_`i'~=.
	quiet replace oop_`i' = 0 if oop_`i'<0
	//plan costs
	quiet gen double emp_`i' = use_`i' - oop_`i'
	//running sums
	quiet replace sum_oop = sum_oop + oop_`i'
	quiet replace sum_employer = sum_employer + emp_`i'
	quiet replace sum_use = sum_use + use_`i'
	
}

//Person, Plan Expected Costs 1 (Correctly calculates OOP of expected OOP costs)
//Part 1: calculate conditional on a draw from the lnNormal part of the distribution
cap drop temp*
cap drop EOOP1*
cap drop Ecost1*
cap drop meanOOP
cap drop varOOP
cap drop meanUse
quiet gen double EOOP1 = sum_oop/(`Q')
quiet gen double Ecost1 = sum_emp/(`Q')
quiet gen double meanUse = sum_use/(`Q')

//a quick and dirty check that simulating the mean gets the mean basically correct for the lognormal part
gen temp_mean = exp(lnN_u + .5*lnN_sig*lnN_sig) //formula for lnNormal mean
compare temp_mean meanUse
summ temp_mean meanUse
//check the full prediction
replace temp_mean = temp_mean*(1-Pr_zero)
compare preddoc temp_mean

//Part 2: calculate conditional on the zero point mass
replace EOOP1 = EOOP1*(1-Pr_zero)
replace Ecost1 = Ecost1*(1-Pr_zero)

ta plan, summ(Ecost1)


cap drop temp*
cap drop Ecost1H 
cap drop Ecost1L
cap drop Ecost1N
egen temp1 = max(Ecost1) if plan=="B", by(enrolid year)
egen Ecost1H = max(temp1), by(enrolid year)
label var Ecost1H "H Employer expected costs"
egen temp2 = max(Ecost1) if plan=="A", by(enrolid year)
egen Ecost1L = max(temp2), by(enrolid year)
label var Ecost1L "L Employer expected costs"
egen temp3 = max(Ecost1) if plan=="N", by(enrolid year)
egen Ecost1N = max(temp3), by(enrolid year)
label var Ecost1N "N Employer expected costs"
cap drop temp*
egen temp1 = max(EOOP1) if plan=="B", by(enrolid year)
egen EOOP1H = max(temp1), by(enrolid year)
label var EOOP1H "H OOP of expected costs"
egen temp2 = max(EOOP1) if plan=="A", by(enrolid year)
egen EOOP1L = max(temp2), by(enrolid year)
label var EOOP1L "L OOP of expected costs"
egen temp3 = max(EOOP1) if plan=="N", by(enrolid year)
egen EOOP1N = max(temp3), by(enrolid year)
label var EOOP1N "N OOP of expected costs"


foreach var in EOOP1 EOOP2 Ecost1 Ecost2{
	gen `var'diff1 = `var'H - `var'L
	label var `var'diff1 "`var'H - `var'L"
	
	gen `var'diff2 = `var'H - `var'N
	label var `var'diff2 "`var'H - `var'N"
}

/*----------------------------------------
Save
----------------------------------------*/

set seed 6187 //random.org 1 to 10,000 
gen uniform = uniform()

/*
*save "$WORK/Data/Main_wRandoms.dta", replace


clear
clear mata
clear matrix
set mem 6g
set more off

global SOURCE "/disk/aging/medstat/data/sas"
global BULK "/disk/agebulk2/medstat.work/gerusom"
global WORK "/disk/agedisk3/medstat.work/gerusom"
global SCRATCH "/disk/agescratch4/gerusom"

global DISTR "/disk/agedisk3/medstat.work/gerusom/Results/Distr"

*sysdir set PERSONAL "/disk/homes2b/nber/gerusom/ado/plus/personal"
sysdir set PERSONAL "/disk/homedirs/gerusom/ado/plus/personal"

use "$WORK/Data/Main_wRandoms.dta", clear

*/

*----------------------------------------------------
*----------------------------------------------------
*----ESITMATE
*----------------------------------------------------
*----------------------------------------------------


	cap drop sample
	gen sample = 1 if emprel==1 & count_fam==1 & preddoc~=. & lnN_u~=.
	
	cap drop choose
	gen choose = .
	replace choose = 1 if plan=="A" & B_hour==0
	replace choose = 1 if plan=="B" & B_hour==1
	replace choose = 0 if plan=="A" & B_hour==1
	replace choose = 0 if plan=="B" & B_hour==0

	replace choose = 1 if plan=="A" & B_sal==0
	replace choose = 1 if plan=="B" & B_sal==1
	replace choose = 0 if plan=="A" & B_sal==1
	replace choose = 0 if plan=="B" & B_sal==0

	cap drop price
	gen price = 0
	local price = 695
	replace price = `price' if plan=="B"
	
	cap log close
	log using "$WORK/log/2016-6-21-`price'Q30.log", replace

	mix2 choose gamma if sample==1, epsilon(epsilon_B) shift(agegrp4 agegrp3 agegrp2 female planB) nrep(75) qdraws(30) iterate(20) draws(ioop) group(enrolid) plan(plan) utilization(lnN_u) sd(lnN_sig) przero(Pr_zero) burn(50) price(price)  trace

	cap log close

