



clear
clear mata
clear matrix
set mem 6g
set more off

global SOURCE "/disk/aging/medstat/data/sas"
global BULK "/disk/agebulk2/medstat.work/gerusom"
global WORK "/disk/agedisk3/medstat.work/gerusom"
global SCRATCH "/disk/agescratch4/gerusom"

global DISTR "/disk/agedisk3/medstat.work/gerusom/Results/Distr"

sysdir set PERSONAL "/disk/homes2b/nber/gerusom/ado/plus/personal"



/*----------------------------------------
Set Prices as local vars
----------------------------------------*/


//cols: Price | Q | Delta P | Delta Q | Delta W | Delta Actuarial

//set optimal prices for welfare calcs here:

local pbase  = 695
local puni   = 255
local p_age1 = 145
local p_age2 = 220
local p_age3 = 270
local p_age4 = 350
local p_m    = 210
local p_w    = 310

/*----------------------------------------
first calculate welfare, takeup, and AV at these prices
----------------------------------------*/


//AV = E(Insurer Payout) - Price | group

use "$WORK/Data/Main_wRandoms.dta", clear

cap drop coeff_*
gen coeff_eps = 1350
gen coeff_gamma = .0006957
gen coeff_ag2_4 = 508
gen coeff_ag2_3 = 322
gen coeff_ag2_2 = 261
gen coeff_female = 179
gen coeff_planB = -832


gen coeff_alt_eps = coeff_eps

*----------------------------------------------------------
*----------------------------------------------------------
*----First calculate the portion of the utility function that can be separated out from DeltaP and epsilon
*----Call this Wj = INT[exp(gamma(OOP - Planj - femj - SUM(agej)))dFj(OOP)]. All items in money term drop out for plan L, except OOP
*----Note no negative sign before exp()
*----Choice will be to choose H iff: 
*----exp(gamma(deltaP - eps))*-WH > -WL
*----exp(gamma(deltaP - eps))*WH < WL
*----Which is the same as deltaP + eps < ln(WL/WH)/gamma

*Distribution of medical cost risk
cap drop use_*
cap drop oop_*
local Q = 200

forvalues i=1(1)`Q'{
	*want Pr always to lie btwn 0 and 1, (thus cant have it equal Q/Q or 0/Q)
	local Pr = `i'/`Q' - 1/(2*`Q')
	quiet gen use_`i' = exp(lnN_u + lnN_sig*invnormal(`Pr'))
}

*Distribution of OOP risk, based on medical risk (use_i)
forvalues i=1(1)`Q'{
	quiet gen double oop_`i' = use_`i' if use_`i'<ided_
	quiet replace oop_`i' = ided_ + (use_`i'-ided_)*coins_ if use_`i'>ided_ & use_`i'~=.
	quiet replace oop_`i' = ioop_ if oop_`i'>ioop_ & use_`i'~=.
	quiet replace oop_`i' = 0 if oop_`i'<0
}

*simulation draws for numerically integrating to expected utility
cap drop sum
gen double sum = 0
forvalues i=1(1)`Q'{
	quiet replace sum = sum + exp(coeff_gamma*(oop_`i' - agegrp2*coeff_ag2_2 - agegrp3*coeff_ag2_3 - agegrp4*coeff_ag2_4 - female*coeff_fem - planB*coeff_planB))
}


*----Expected utility needs to also average in the utility of zero OOP loss, which hasn't been accounted for yet.
cap drop W_j
cap drop W_distr
quiet gen double W_distr = sum/(`Q') //welfare of the positive spending outcome
cap drop W_zero //welfare of the no-spending outcome

*After taking expectation of utility over non-zero portion of utilization distribution, avg with zero mass
*E(U(use>0))*Pr(use>0) + E(U(0))*Pr(use=0)
gen W_zero = exp(coeff_gamma*(0 - agegrp2*coeff_ag2_2 - agegrp3*coeff_ag2_3 - agegrp4*coeff_ag2_4 - female*coeff_fem - planB*coeff_planB))
gen W_j = W_distr*(1-Pr_zero) + W_zero*Pr_zero if sample==1

cap drop W_zero
cap drop W_distr
cap drop sum


*----------------------------------------------------------
*----------------------------------------------------------
*----Next calculate the fraction of epsilons that generate a choice of H 
*----This will be conditional on some deltaP
*----choose H iff: deltaP - eps < ln(WL/WH)/gamma

*----Get WH and WL on same obs (line)

cap drop temp*
cap drop WH
cap drop WL
cap drop WN
egen temp = max(W_j) if plan=="B", by(enrolid year)
egen WH = max(temp), by(enrolid year)
cap drop temp
egen temp = max(W_j) if plan=="A", by(enrolid year)
egen WL = max(temp), by(enrolid year)
cap drop temp
egen temp = max(W_j) if plan=="N", by(enrolid year)
egen WN = max(temp), by(enrolid year)

gen utilityH = (ln(WL) - ln(WH))/coeff_gamma 
gen utilityAltH = (ln(WN) - ln(WH))/coeff_gamma
	
/**********************************************************************************
***********************************************************************************

Simulate Choices under new prices

***********************************************************************************
**********************************************************************************/

//Ecost1diff1 = the correct measure of MC comparing H to L
//Ecost1diff2 =the correct measure of MC comparing H to N, should be equal to ECcost1H

cap drop W_tot_*
cap drop PrH_*
cap drop AC_*
cap drop MC_*
cap drop AV_*

cap drop W_tot_alt_*
cap drop PrH_alt_*
cap drop AC_alt_*
cap drop MC_*

//Outer loop: Price. Inner loop: sum over epsilon.

//forvalues P=0(10)1000{
foreach price in pbase puni p_age1  p_age2 p_age3 p_age4 p_m p_w{

	cap drop sum_H
	cap drop sum_MC
	cap drop sum_W
	cap drop sum_AV
	cap drop sum_altH
	cap drop sum_altMC
	cap drop sum_altW
		
	quiet gen sum_H = 0
	quiet gen sum_MC = 0
	quiet gen sum_W = 0 	//comparing H to L
	quiet gen sum_AV = 0 
	quiet gen sum_altH = 0
	quiet gen sum_altMC = 0
	quiet gen sum_altW = 0	//comparing H to nothing

	local P = ``price''
	di "Price: " `P'
	
	//Generate plan choice conditional on epsilon realization
	local R = 200
	forvalues i=1(1)`R'{
		*want Pr always to lie btwn 0 and 1, (thus cant have it equal Q/Q or 0/Q)
		local Pr = `i'/`R' - 1/(2*`R')
	
		quiet replace sum_H = sum_H + 1 if `P' - coeff_eps*invnormal(`Pr') < utilityH
		cap drop temp_chooseH
		quiet gen temp_chooseH = 0
		quiet replace temp_chooseH = 1 if `P' - coeff_eps*invnormal(`Pr') < utilityH
		
		quiet replace sum_MC = sum_MC + Ecost1diff1 if temp_chooseH == 1
		quiet replace sum_MC = sum_MC + 0 if temp_chooseH == 0

		quiet replace sum_altH = sum_altH + 1 if `P' - coeff_alt_eps*invnormal(`Pr') < utilityAltH
		cap drop temp_choosealtH
		quiet gen temp_choosealtH = 0
		quiet replace temp_choosealtH = 1 if `P' - coeff_alt_eps*invnormal(`Pr') < utilityAltH
		
		quiet replace sum_altMC = sum_altMC + Ecost1diff2 if temp_choosealtH == 1
		quiet replace sum_altMC = sum_altMC + 0 if temp_choosealtH == 0

		//welfare is the diff between CE and cost
		//-1/gamma * exp(-gamma*CE) = -1/gamma * exp(-gamma*OOPj) \equiv  -1/gamma * Wj
		//implies CE = ln(Wj)/-gamma
		//recall WH = exp(-gamma*W)  = - utility*gamma
		quiet replace sum_W = sum_W + (ln(WH)/(-coeff_gamma) + coeff_eps*invnormal(`Pr') - Ecost1H) if temp_chooseH == 1
		quiet replace sum_W = sum_W + (ln(WL)/(-coeff_gamma) - Ecost1L) if temp_chooseH == 0

		//AV = E(payout) - Price = PrH*EcostH - PrH*PriceH + (1-PrH)*EcostL - (1-PrH)*PriceL
		//AV = PrH*(EcostH - EcostL - DeltaP) + {EcostL - PL}, where the {.} term is const and will drop from any comparisons of AV
		quiet replace sum_AV = sum_AV + Ecost1H - `P' 			if temp_chooseH == 1
		quiet replace sum_AV = sum_AV + Ecost1L				if temp_chooseH == 0


		quiet replace sum_altW = sum_altW + (ln(WH)/(-coeff_gamma) + coeff_alt_eps*invnormal(`Pr') - Ecost1H) if temp_choosealtH == 1
		quiet replace sum_altW = sum_altW + (ln(WN)/(-coeff_gamma) - Ecost1N) if temp_chooseH == 0

	}
	
	//demand curve
	gen PrH_`P' = sum_H/(`R')
	label var PrH_`P' "Pr choose H | deltaPrice = `P'"
	
	//mc curve (probabilistic in the same way as demand)
	gen MC_`P' = sum_MC/(`R')
	label var MC_`P' "(MC of choose H | deltaPrice = `P') = Ecost1*PrH"	
	
	gen W_tot_`P' = sum_W/(`R')
	label var W_tot_`P' "(Total surplus | deltaPrice = `P') = (WH-WL)*PrH"
	
	gen AV_`P' = sum_AV/(`R')
	label var AV_`P' "(AV | deltaPrice = `P') = (EcostH - EcostL - DeltaP)*PrH"	
	
	//demand curve
	gen PrH_alt_`P' = sum_altH/(`R')
	label var PrH_alt_`P' "Pr choose altH | deltaPrice = `P'"
	
	//mc curve (probabilistic in the same way as demand)
	gen MC_alt_`P' = sum_altMC/(`R')
	label var MC_alt_`P' "(MC of choose altH | deltaPrice = `P') = Ecostdiff2*PrHalt"	
	
	gen W_tot_alt_`P' = sum_altW/(`R')
	label var W_tot_alt_`P' "(Total surplus | deltaPrice = `P') = (WH-WN)*PrHalt"


}




//Keep just one observation per person year
keep if planB==1
keep if sample==1


/*----------------------------------------
format into table
----------------------------------------*/

	//sample restrictions
	foreach val in o a1 a2 a3 a4 s1 s2{
		cap drop sample_`val'
	}
	gen sample_o = 1
	gen sample_a1 = ag2==1
	gen sample_a2 = ag2==2
	gen sample_a3 = ag2==3
	gen sample_a4 = ag2==4	
	gen sample_s1 = fem==0
	gen sample_s2 = fem==1

	//weights for later
	//sample restrictions
	foreach val in o a1 a2 a3 a4 s1 s2{
		cap drop n_`val'
		count if sample_`val'
		local n_`val' = r(N)
	}

matrix W = J(42,7,.)

forvalues i = 1(1)4{
	


	//col 1
	local o =  `i'*11 - 10
	local a1 = `i'*11 - 8
	local a2 = `i'*11 - 7
	local a3 = `i'*11 - 6
	local a4 = `i'*11 - 5
	local s1 = `i'*11 - 3
	local s2 = `i'*11 - 2	
	
	local bo =  11 - 10
	local ba1 = 11 - 8
	local ba2 = 11 - 7
	local ba3 = 11 - 6
	local ba4 = 11 - 5
	local bs1 = 11 - 3
	local bs2 = 11 - 2	
	
	matrix W[`o',  1]  = 0
	matrix W[`a1', 1] = 18
	matrix W[`a2', 1] = 30
	matrix W[`a3', 1] = 40
	matrix W[`a4', 1] = 50
	matrix W[`s1', 1] = 1
	matrix W[`s2', 1] = 2	
	

	if `i'==1 {
		foreach val in o a1 a2 a3 a4 s1 s2{
			//col 2
			matrix W[``val'',  2] = `pbase'
			
			//col 3
			quiet summ PrH_`pbase' if sample_`val'==1 
			matrix W[``val'',  3] = r(mean) 
			
			//for later
			quiet summ W_tot_`pbase' if sample_`val'==1
			local Wbase_`val' = r(mean)
			
			quiet summ AV_`pbase' if sample_`val'==1
			local AVbase_`val' = r(mean)			
			
		}
	}

	if `i'==2 {
		foreach val in o a1 a2 a3 a4 s1 s2{
			//col 2
			matrix W[``val'',  2] = `puni'
			
			//col 3
			quiet summ PrH_`puni' if sample_`val'==1 
			matrix W[``val'',  3] = r(mean) 
			
			//col 4 - Delta Price
			matrix W[``val'',  4] =  W[``val'',  2] - W[`b`val'',2]

			//col 5 - Delta Takeup
			matrix W[``val'',  5] =  W[``val'',  3] - W[`b`val'',3] 
			
			//col 6 - Delta Welfare
			quiet summ W_tot_`puni' if sample_`val'==1
			local WNew = r(mean)
			matrix W[``val'',  6] = `WNew' - `Wbase_`val''
			
			//col 7 - Delta AV
			quiet summ AV_`puni' if sample_`val'==1
			local AVNew = r(mean)
			//this formulation assumes the price of the L plan is zero
			matrix W[``val'',  7] = `AVNew' // - `AVbase_`val''
			
		}	
	}	
	
	if `i'==3 {
		//col 2
		matrix W[`a1', 2] = `p_age1'
		matrix W[`a2', 2] = `p_age2'
		matrix W[`a3', 2] = `p_age3'
		matrix W[`a4', 2] = `p_age4'

		foreach val in a1 a2 a3 a4 {

			local loopPrice = W[``val'',2]

			//col 3 - Takeup
			quiet summ PrH_`loopPrice' if sample_`val'==1 
			matrix W[``val'',  3] = r(mean) 
						
			//col 4 - Delta Price
			matrix W[``val'',  4] =  W[``val'',  2] - W[`b`val'',2]

			//col 5 - Delta Takeup
			matrix W[``val'',  5] =  W[``val'',  3] - W[`b`val'',3] 
			
			//col 6 - Delta Welfare
			quiet summ W_tot_`loopPrice' if sample_`val'==1
			local WNew = r(mean)
			matrix W[``val'',  6] = `WNew' - `Wbase_`val''
			
			//col 7 - Delta AV
			quiet summ AV_`loopPrice' if sample_`val'==1
			local AVNew = r(mean)
			//this formulation assumes the price of the L plan is zero
			matrix W[``val'',  7] = `AVNew' // - `AVbase_`val''
				
		}
		//find average of takeup and welfare effects
		//takeup
		matrix W[`o',  3] = (W[`a1',  3]*`n_a1' +  W[`a2',  3]*`n_a2' + W[`a3',  3]*`n_a3' + W[`a4',  3]*`n_a4')/(`n_a1' + `n_a2' + `n_a3' + `n_a4')
		//delta takeup
		matrix W[`o',  5] =  W[`o',  3] - W[`bo', 3] 
		//Welfare
		matrix W[`o',  6] = (W[`a1',  6]*`n_a1' +  W[`a2',  6]*`n_a2' + W[`a3',  6]*`n_a3' + W[`a4',  6]*`n_a4')/(`n_a1' + `n_a2' + `n_a3' + `n_a4')
	}
		
	if `i'==4 {
		//col2
		matrix W[`s1', 2] = `p_m'
		matrix W[`s2', 2] = `p_w'
		foreach val in s1 s2 {

			local loopPrice = W[``val'',2]

			//col 3 - Takeup
			quiet summ PrH_`loopPrice' if sample_`val'==1 
			matrix W[``val'',  3] = r(mean) 
						
			//col 4 - Delta Price
			matrix W[``val'',  4] =  W[``val'',  2] - W[`b`val'',2]

			//col 5 - Delta Takeup
			matrix W[``val'',  5] =  W[``val'',  3] - W[`b`val'',3] 
			
			//col 6 - Delta Welfare
			quiet summ W_tot_`loopPrice' if sample_`val'==1
			local WNew = r(mean)
			matrix W[``val'',  6] = `WNew' - `Wbase_`val''
			
			//col 7 - Delta AV
			quiet summ AV_`loopPrice' if sample_`val'==1
			local AVNew = r(mean)
			//this formulation assumes the price of the L plan is zero
			matrix W[``val'',  7] = `AVNew' // - `AVbase_`val''
				
		}
		//find average of takeup and welfare effects
		//takeup
		matrix W[`o',  3] = (W[`s1',  3]*`n_s1' +  W[`s2',  3]*`n_s2')/(`n_s1' + `n_s2')
		//delta takeup
		matrix W[`o',  5] =  W[`o',  3] - W[`bo', 3] 
		//Welfare
		matrix W[`o',  6] = (W[`s1',  6]*`n_s1' +  W[`s2',  6]*`n_s2')/(`n_s1' + `n_s2')
	}

}

matrix list W
xml_tab W, save("$WORK`c(dirsep)'Results2016`c(dirsep)'Tables`c(dirsep)'welfareMain_695") replace









